capture log close sublog
log using "$prdir/log/analysis/qcew/treatment_effect_nicegraphs_2013.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Graph the treatment effect results from the synthetic control and
* the placebo synthetic control estimations and differencing (2013 - 2018)
* Author: Justin Wiltshire
	
* Updated: November 14, 2019
*-------------------------------------------------------------------------------

local c = 7400

* Change settings for the synthetic control
set matsize 11000
	
* Run employment synthetic control for Orlando, selected NAICS supersectors
foreach ind of numlist 10 23 44 72 {
		  
	* Run for each variable				
	foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
		local pdflist
						
		* Difference the data
		use "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/deseasonalize_n`ind'_merged_2013.dta", clear
		reshape long tr_effect_, i(_time time) j(cz)
		sort cz _time
		if "`lhs'" == "resid_ln_emp" {
			qui sum tr_effect_ if _time == 692, d
		}
		else if "`lhs'" != "resid_ln_emp" {
			qui sum tr_effect_ if time == 230, d
		}
									
		* Identify the placebo pre-treatment period `treatment effects' to difference out later
		if cz != 7400 {
			if "`lhs'" == "resid_ln_emp" {
				qui gen q2_te_ = tr_effect_ if _time == 691
				bysort cz (_time): replace q2_te_ = q2_te[56]
			}
			else if "`lhs'" != "resid_ln_emp" {
				qui gen q2_te_ = tr_effect_ if _time == 688
				bysort cz (_time): replace q2_te_ = q2_te[18]
			}
		}
						
		* Create macros with the number of placebos for the plot legend
		levelsof(cz), local(CZ)
		distinct cz
		local LA = r(ndistinct) + 1
		local Orlando = r(ndistinct) + 2
				
		* Clean up and reshape back
		reshape wide tr_effect_ q2_te_, i(_time time tr_effect_orl) j(cz)
                               
		* Identify the Orlando pre-treatment period `treatment effect' to difference out later
		if "`lhs'" == "resid_ln_emp" {
			qui gen q2_te_orl = tr_effect_orl if _time == 691
			replace q2_te_orl = q2_te_orl[56]                                 
		}
		else if "`lhs'" != "resid_ln_emp" {
			qui gen q2_te_orl = tr_effect_orl if _time == 688
			replace q2_te_orl = q2_te_orl[18]
		}
							
		* Create locals for the placebo results and put treatment effects in percent terms
		local placebos
		foreach czone of local CZ {
			if "`czone'" != "7400" {
				if "`lhs'" == "resid_ln_emp" {
					local placebos "`placebos' line tr_effect_`czone' _time if inrange(tr_effect_`czone', -10, 10), lcolor(gs8) lwidth(vthin) || "
				}
				else if "`lhs'" != "resid_ln_emp" {
					local placebos "`placebos' line tr_effect_`czone' time if inrange(tr_effect_`czone', -10, 10), lcolor(gs8) lwidth(vthin) || "
				}
				qui replace tr_effect_`czone' = 100*tr_effect_`czone'
				qui replace q2_te_`czone' = 100*q2_te_`czone'
			}
		}
			   
		* Put the orlando treatment effects in percent terms
		qui replace tr_effect_orl = 100*tr_effect_orl
		qui replace q2_te_orl = 100*q2_te_orl
		
		* Define the locals to use for the graph titles
		if "`lhs'" == "resid_ln_emp" {
			local var = "`r_title'log employment"
			local var_label "employment"
		}
		else if "`lhs'" == "resid_ln_wagebill" {
			local var = "`r_title'log total compensation"
			local var_label "compensation (total)"
		}
		else if "`lhs'" == "resid_ln_avg_wkly_wage" {
			local var = "`r_title'log compensation per worker"
			local var_label "compensation per worker"
		}
		else if "`lhs'" == "resid_ln_estabs" {
			local var = "`r_title'log total establishments"
			local var_label "establishments"
		}
          
		* Create the graphs
		if "`lhs'" == "resid_ln_emp" {
		  #delimit ;
				twoway  
					`placebos'||
					(line tr_effect_38300 _time if inrange(tr_effect_38300, -10, 10), lcolor(black) lp(shortdash)) ||
					(line tr_effect_orl _time if inrange(tr_effect_orl, -10, 10), lcolor(black)),
					xline(691.5, lwidth(2) lcolor(gs12))
					xline(691 692, lp(dot) lcolor(gs8)) xtitle("") ytitle("`var'")
					xtitle("") ytitle("Gap (%)")
					plotregion(margin(zero))
					yscale(range(-10 10)) ylabel(-10 (4) 10)
					graphregion(fcolor(white))
					legend(order(`Orlando' "Orlando" `LA' " Los Angeles"));
				#delimit cr
		}
		else if "`lhs'" != "resid_ln_emp" {
			#delimit ;
				twoway 
					`placebos'||
					(line tr_effect_38300 time if inrange(tr_effect_38300, -10, 10), lcolor(black) lp(shortdash)) ||
					(line tr_effect_orl time if inrange(tr_effect_orl, -10, 10), lcolor(black)),
					xline(229.5, lwidth(6) lcolor(gs12))
					xline(229 230, lp(dot) lcolor(gs8)) xtitle("") ytitle("`var'")
					xtitle("") ytitle("Gap (%)")
					plotregion(margin(zero))
					yscale(range(-10 10)) ylabel(-10 (4) 10)
					graphregion(fcolor(white))
					legend(order(`Orlando' "Orlando" `LA' " Los Angeles"));
				#delimit cr
		}
				
		nicepdf "$prdir/out/analysis/cz_7400/nice_graphs/te/te_`lhs'_n`ind'_2013.pdf", replace
					
						
		*** Difference the pre-treatment period `treatment effects' and graph
		* Difference out the pre-treatment period `treatment effect'
		foreach czone of local CZ {
			if "`czone'" != "7400" {
				qui replace tr_effect_`czone' = tr_effect_`czone' - q2_te_`czone'
			}
        }
		qui replace tr_effect_orl = tr_effect_orl - q2_te_orl
				
		* Create the graphs
		if "`lhs'" == "resid_ln_emp" {
			#delimit ;
				twoway 
					`placebos'||
					(line tr_effect_38300 _time if inrange(tr_effect_38300, -10, 10), lcolor(black) lp(shortdash)) ||
					(line tr_effect_orl _time if inrange(tr_effect_orl, -10, 10), lcolor(black)),
					xline(691.5, lwidth(2) lcolor(gs12))
					xline(691 692, lp(dot) lcolor(gs8)) xtitle("") ytitle("`var'") 
					xtitle("") ytitle("Gap vs final pre-treatment period (%)")
					plotregion(margin(zero))
					yscale(range(-10 10)) ylabel(-10 (4) 10)
					graphregion(fcolor(white))
					legend(order(`Orlando' "Orlando" `LA' " Los Angeles"));
				#delimit cr
		}
		else if "`lhs'" != "resid_ln_emp" {
			#delimit ;
				twoway 
					`placebos'||
					(line tr_effect_38300 time if inrange(tr_effect_38300, -10, 10), lcolor(black) lp(shortdash)) ||
					(line tr_effect_orl time if inrange(tr_effect_orl, -10, 10), lcolor(black)),
					xline(229.5, lwidth(6) lcolor(gs12))
					xline(229 230, lp(dot) lcolor(gs8)) xtitle("") ytitle("`var'")
					xtitle("") ytitle("Gap vs final pre-treatment period (%)")
					plotregion(margin(zero))
					yscale(range(-10 10)) ylabel(-10 (4) 10)
					graphregion(fcolor(white))
					legend(order(`Orlando' "Orlando" `LA' " Los Angeles"));
				#delimit cr
		}
		nicepdf "$prdir/out/analysis/cz_7400/nice_graphs/te_alternate/te_`lhs'_n`ind'_2013.pdf", replace
	}
}


* Close the log file
log close sublog
