capture log close sublog
log using "$prdir/log/analysis/qcew/combined_final_graphs.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Graph the three combination graphs--two with the synthetic controls
* and one with the gaps/treatment effects
* Author: Justin Wiltshire
	
* Updated: December 21, 2021
*-------------------------------------------------------------------------------

local c = 7400

* Settings
set matsize 11000
local graphlist_emp ""
local graphlist_earn ""
local graphlist_te_emp ""

* Create the graphs
local naics "10 23 44 72" 
foreach ind of local naics {
	foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage {
		use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`lhs'/deseasonalize_n`ind'.dta", clear
		
		* Create labels and titles
		if `ind' == 10 {
			local ind_label "Panel A: Aggregate"
			local tlab "tlabel(`""')"
			local urange = 0.15
			local incticks = 0.05
		}
		else if `ind' == 23 {
			local ind_label "Panel B: Construction"
			local tlab "tlabel(`""')"
			local urange = 0.4
			local incticks = 0.1
		}
		else if `ind' == 44 {
			local ind_label "Panel C: Retail"
			local tlab "tlabel(2014m1(12)2018m1, angle(45))"
			local urange = 0.15
			local incticks = 0.05
		}
		else if `ind' == 72 {
			local ind_label "Panel D: Hospitality"
			local tlab "tlabel(2014m1(12)2018m1, angle(45))"
			local urange = 0.15
			local incticks = 0.05
		}
		
		* Normalize things so Orlando is 0 at the beginning of the series
		qui gen x = _Y_treat[1]
		qui egen orl_0 = max(x)
		qui gen y_treat = _Y_treat - orl_0
		qui gen y_synth = _Y_synth - orl_0
			
		* Create the graphs
		tsset _time, monthly
		if "`lhs'" == "resid_ln_emp" {
			#delimit ;
				twoway 
					(line y_treat _time, lcolor(black)) || (line y_synth _time, lcolor(gs8) lp(dash)), 
					xline(691.5, lwidth(1) lcolor(gs12))
					xline(691 692, lp(dot) lcolor(gs8)) 
					title("`ind_label'") xtitle("") ytitle("")
					yscale(range(0 `urange'))
					ylabel(0(`incticks')`urange')
					`tlab' ttick(#5)
					graphregion(fcolor(white)) plotregion(fcolor(white) margin(0 0 0 0)) bgcolor(white)
					legend(label(1 "Orlando") label(2 "Synthetic Orlando") region(lwidth(thin) lcolor(gs10)));
				#delimit cr
				
			* Copy it
			graph copy gr_emp`ind', replace
			local graphlist_emp "`graphlist_emp' gr_emp`ind'"
		}
	
		else if "`lhs'" != "resid_ln_emp" {
			#delimit ;
				twoway 
					(line y_treat _time, lcolor(black)) || (line y_synth _time, lcolor(gs8) lp(dash)), 
					xline(692.5, lwidth(4) lcolor(gs12))
					xline(691 694, lp(dot) lcolor(gs8)) 
					title("`ind_label'") xtitle("") ytitle("")
					yscale(range(-0.05 0.15))
					ylabel(-0.05(0.05)0.15)
					`tlab' ttick(#5)
					graphregion(fcolor(white)) plotregion(fcolor(white) margin(0 0 0 0)) bgcolor(white)
					legend(label(1 "Orlando") label(2 "Synthetic Orlando") region(lwidth(thin) lcolor(gs10)));
				#delimit cr
				
			* Copy it
			graph copy gr_earn`ind', replace
			local graphlist_earn "`graphlist_earn' gr_earn`ind'"
		}
	}	
}

* Place all the employment plots on one graph, and all the earnings plots on one graph
qui capture mkdir "$prdir/out/analysis/cz_7400/nice_graphs/combined"
qui grc1leg `graphlist_emp', imargin(vsmall) legendfrom(gr_emp72)
qui graph export "$prdir/out/analysis/cz_7400/nice_graphs/combined/sc_combined_emp_qcew.pdf", replace
qui grc1leg `graphlist_earn', imargin(vsmall) legendfrom(gr_earn72)
qui graph export "$prdir/out/analysis/cz_7400/nice_graphs/combined/sc_combined_earn_qcew.pdf", replace

* Run employment synthetic control for Orlando, selected NAICS supersectors
foreach ind of numlist 10 23 44 72 {
		  
	* Create labels and titles
	if `ind' == 10 {
		local ind_label "Panel A: Aggregate"
		local tlab "tlabel(`""')"
	}
	else if `ind' == 23 {
		local ind_label "Panel B: Construction"
		local tlab "tlabel(`""')"
	}
	else if `ind' == 44 {
		local ind_label "Panel C: Retail"
		local tlab "tlabel(2014m1(12)2018m1, angle(45))"
	}
	else if `ind' == 72 {
		local ind_label "Panel D: Hospitality"
		local tlab "tlabel(2014m1(12)2018m1, angle(45))"
	}
						
	* Difference the data
	use "$prdir/dta/analysis/qcew/sc_merged/cz_7400/resid_ln_emp/deseasonalize_n`ind'_merged.dta", clear
	reshape long tr_effect_, i(_time time) j(cz)
	sort cz _time
	qui sum tr_effect_ if _time == 692, d
								
	* Identify the placebo pre-treatment period `treatment effects' to difference out later
	if cz != 7400 {
		qui gen q2_te_ = tr_effect_ if _time == 691
		bysort cz (_time): replace q2_te_ = q2_te[44]
	}
						
	* Create macros with the number of placebos for the plot legend
	levelsof(cz), local(CZ)
	distinct cz
	local LA = r(ndistinct) + 1
	local Orlando = r(ndistinct) + 2
				
	* Clean up and reshape back
	reshape wide tr_effect_ q2_te_, i(_time time tr_effect_orl) j(cz)
                               
	* Identify the Orlando pre-treatment period `treatment effect' to difference out later
	qui gen q2_te_orl = tr_effect_orl if _time == 691
	replace q2_te_orl = q2_te_orl[44]                                 
							
	* Create locals for the placebo results and put treatment effects in percent terms
	local placebos
	foreach czone of local CZ {
		if "`czone'" != "7400" {
			local placebos "`placebos' line tr_effect_`czone' _time if inrange(tr_effect_`czone', -10, 10), lcolor(gs8) lwidth(vthin) lp(solid) || "
			qui replace tr_effect_`czone' = 100*tr_effect_`czone'
			qui replace q2_te_`czone' = 100*q2_te_`czone'
		}
	}
			   
	* Put the orlando treatment effects in percent terms
	qui replace tr_effect_orl = 100*tr_effect_orl
	qui replace q2_te_orl = 100*q2_te_orl

	* Create the graphs
	#delimit ;
		twoway  
			`placebos'||
			(line tr_effect_38300 _time if inrange(tr_effect_38300, -10, 10), lcolor(black) lp(shortdash)) ||
			(line tr_effect_orl _time if inrange(tr_effect_orl, -10, 10), lcolor(black) lp(solid)),
			xline(691.5, lwidth(1.5) lcolor(gs12))
			xline(691 692, lp(dot) lcolor(gs8)) 
			title("`ind_label'") xtitle("") ytitle("")
			`tlab'
			plotregion(margin(zero))
			yscale(range(-10 10)) ylabel(-10 (4) 10)
			graphregion(fcolor(white))
			legend(order(`Orlando' "Orlando" `LA' " Los Angeles") region(lwidth(thin) lcolor(gs10)));
		#delimit cr
		
	* Copy it
	graph copy gr_emp`ind', replace
	local graphlist_te_emp "`graphlist_te_emp' gr_emp`ind'"
}

* Combine the the employment TE plots into a single graph
qui grc1leg `graphlist_te_emp', imargin(vsmall) legendfrom(gr_emp72)
qui graph export "$prdir/out/analysis/cz_7400/nice_graphs/combined/te_combined_emp_qcew.pdf", replace


* Close the log file
log close sublog
