capture log close sublog
log using "$prdir/log/analysis/qcew/dd.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: DD analysis of deseasonalized QCEW variables, by CZ
* Author: Justin Wiltshire

* Updated: August 3, 2020
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* Positive-weighted CZs from each synthetic control as controls
*-------------------------------------------------------------------------------

tempfile core
foreach ind in 10 23 44 72 {
	foreach lhs in emp avg_wkly_wage estabs {

		* Load the synthetic control weights
		qui use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/resid_ln_`lhs'/deseasonalize_n`ind'.dta", clear

		* Clean up and save tempfile
		qui rename (_Co_Number _W_Weight) (cz wt)
		gsort -wt
		qui keep if wt > 0
		qui keep cz wt
		qui save "`core'", replace
		
		* Load the cleaned and deseasonalized QCEW data
		qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
		qui merge m:1 cz using "`core'", norep
		qui keep if cz == 7400 | _m == 3
		qui keep if naics == `ind'
		qui drop _m
		qui sort cz tm
		
		* tsset where necessary
		tsset cz tm
		
		* Create key variables
		qui gen trunit = (cz == 7400)
		if "`lhs'" == "emp" {
			qui gen trperiod = (tm >= 692)
		}
		else if "`lhs'" != "emp" {
			
			* Non-employment variables are only observed quarterly
			keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
			qui gen trperiod = (tm >= 691)
		}
			
		*** Run the regressions and capture the results
		
		* Time FEs
		qui reg resid_ln_`lhs' i.trunit##trperiod prop_emp_23 prop_emp_72 i.tm, vce(robust)
		mat tmfe_`ind'_`lhs' = [_b[1.trunit#1.trperiod]],[_se[1.trunit#1.trperiod]]
		starmat stars_tmfe_`ind'_`lhs' tmfe_`ind'_`lhs'[1,1]/tmfe_`ind'_`lhs'[1,2] `e(df_r)'
				
		* Unit and time FEs
		qui xtreg resid_ln_`lhs' i.trunit##trperiod prop_emp_23 prop_emp_72 i.tm, fe vce(robust)
		mat bothfe_`ind'_`lhs' = [_b[1.trunit#1.trperiod]],[_se[1.trunit#1.trperiod]]
		starmat stars_bothfe_`ind'_`lhs' bothfe_`ind'_`lhs'[1,1]/bothfe_`ind'_`lhs'[1,2] `e(df_r)'
			
		* Append matrices and tables
		if "`lhs'" == "emp" {
			foreach q in tmfe bothfe {
				mat `q'_`ind' = `q'_`ind'_emp
				mat stars_`q'_`ind' = stars_`q'_`ind'_emp
			}
		}
		if "`lhs'" != "emp" {
			foreach q in tmfe bothfe {
				mat `q'_`ind' = [`q'_`ind']\[`q'_`ind'_`lhs']
				mat stars_`q'_`ind' = [stars_`q'_`ind']\[stars_`q'_`ind'_`lhs']
			}
		}
	}
}

*-------------------------------------------------------------------------------
* Synthetic control as only control
*-------------------------------------------------------------------------------

tempfile core
foreach ind in 10 23 44 72 {
	foreach lhs in emp avg_wkly_wage estabs {

		* Load the synthetic control weights
		qui use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/resid_ln_`lhs'/deseasonalize_n`ind'.dta", clear

		* Clean up and save tempfile
		qui rename (_Co_Number _W_Weight) (cz wt)
		qui keep if wt > 0
		qui keep cz wt
		qui save "`core'", replace
		
		* Load the cleaned and deseasonalized QCEW data
		qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
		qui merge m:1 cz using "`core'", norep
		qui keep if cz == 7400 | _m == 3
		qui keep if naics == `ind'
		qui drop _m
		qui sort cz tm
		
		* Create key variables for collapse
		qui gen trunit = (cz == 7400)
		qui replace resid_ln_`lhs' = wt*resid_ln_`lhs' if trunit == 0
		
		* Collapse
		qui collapse (sum) resid_ln_`lhs', by(tm trunit)
		
		* Create key variables
		if "`lhs'" == "emp" {
			qui gen trperiod = (tm >= 692)
		}
		else if "`lhs'" != "emp" {
			
			* Non-employment variables are only observed quarterly
			keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
			qui gen trperiod = (tm >= 691)
		}
			
		*** Run the regressions and capture the results
				
		* Time FEs
		qui reg resid_ln_`lhs' i.trunit##trperiod i.tm, vce(robust)
		mat sc_`ind'_`lhs' = [_b[1.trunit#1.trperiod]],[_se[1.trunit#1.trperiod]]
		starmat stars_sc_`ind'_`lhs' sc_`ind'_`lhs'[1,1]/sc_`ind'_`lhs'[1,2] `e(df_r)'
			
		* Append matrices and tables
		if "`lhs'" == "emp" {
			mat sc_`ind' = sc_`ind'_emp
			mat stars_sc_`ind' = stars_sc_`ind'_emp
		}
		if "`lhs'" != "emp" {
			mat sc_`ind' = [sc_`ind']\[sc_`ind'_`lhs']
			mat stars_sc_`ind' = [stars_sc_`ind']\[stars_sc_`ind'_`lhs']
		}
	}

	* Create titles for tables
	if "`ind'" == "10" {
		local titname "All sectors"
	}
	if "`ind'" == "23" {
		local titname "Construction sector"
	}
	if "`ind'" == "44" {
		local titname "Retail sector"
	}
	if "`ind'" == "72" {
		local titname "Hospitality sector"
	}
	
	* Create tables
	foreach q in tmfe bothfe sc {
		if "`q'" == "tmfe" {
			local merl ""
			local columnn "Orlando v. all positively-weighted donor units"
			local columnn2 "Time fixed effects"
		}
		if "`q'" == "bothfe" {
			local merl "merge"
			local columnn "Orlando v. all positively-weighted donor units"
			local columnn2 "Time and unit fixed effects"
		}
		if "`q'" == "sc" {
			local merl "merge"
			local columnn "Orlando v. synthetic control"
			local columnn2 "Time fixed effects"
		}

		* Make the tables
		#delimit ;
			frmttable using "$prdir/out/analysis/cz_7400/tables/DD/allpos_sc_regressions_`ind'", replace 
			tex statmat(`q'_`ind') substat(1) sdec(4) annotate(stars_`q'_`ind') asymbol(*,**,***)
			title("Estimated TEs of Hurricane Maria on Orlando (regressions models)""`titname'")
			ctitles("","`columnn'"\"","`columnn2'")
			rtitles("Log employment"\""\"Log earnings/worker"\""\"Log establishments"\"") `merl' ;
		#delimit cr
	}
}

*-------------------------------------------------------------------------------
* Synthetic control as only control, test for pre-trend
*-------------------------------------------------------------------------------

tempfile core
foreach lhs in emp avg_wkly_wage {
	foreach ind in 10 23 44 72 {

		* Load the synthetic control weights
		qui use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/resid_ln_`lhs'/deseasonalize_n`ind'.dta", clear

		* Clean up and save tempfile
		qui rename (_Co_Number _W_Weight) (cz wt)
		qui keep if wt > 0
		qui keep cz wt
		qui save "`core'", replace
		
		* Load the cleaned and deseasonalized QCEW data
		qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
		qui merge m:1 cz using "`core'", norep
		qui keep if cz == 7400 | _m == 3
		qui keep if naics == `ind'
		qui drop _m
		qui sort cz tm

		* Create key variables for collapse
		qui gen trunit = (cz == 7400)
		qui replace resid_ln_`lhs' = wt*resid_ln_`lhs' if trunit == 0
		
		* Collapse
		qui collapse (sum) resid_ln_`lhs', by(tm trunit)
		
		* Create key variables
		if "`lhs'" == "emp" {
			qui gen trperiod = (tm >= 692)
		}
		else if "`lhs'" != "emp" {
			
			* Non-employment variables are only observed quarterly
			keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
			qui gen trperiod = (tm >= 691)
		}
		
		* Break the pre-period into two-quarter periods
		qui levelsof tm, local(x)
		local s = 1
		qui gen s = .
		foreach t of local x {
			qui replace s = `s' if tm == `t'
			local s = `s' + 1
		}
		if "`lhs'" == "emp" {
			qui replace s = ceil(s/6)
		}
		if "`lhs'" != "emp" {
			qui replace s = ceil(s/2)
		}
		
		*** Run the regressions and capture the results
			
		* Time FEs
		qui reg resid_ln_`lhs' ib0.trunit##ib7.s i.tm, vce(robust)
		
		* Save the coefficient and CI estimates to a matrix
		mat rtable = r(table)'
		mat tmfe_`ind'_`lhs' = [rtable[23..28,1..2]\rtable[30..32,1..2]]
		
		* Save the info for star annotation of the table
		matrix stars_tmfe_`ind'_`lhs' = J(6,1,0)
		forval k = 23/28 {
			local x = `k' - 22
			mat stars_tmfe_`ind'_`lhs'[`x',1] = ///
			(abs(rtable[`k',3]) > invttail(`e(df_r)',0.10/2)) + ///
			(abs(rtable[`k',3]) > invttail(`e(df_r)',0.05/2)) + ///
			(abs(rtable[`k',3]) > invttail(`e(df_r)',0.01/2))
		}
		matrix stars_tmfe_`ind'_`lhs'2 = J(3,1,0)
		forval k = 30/32 {
			local x = `k' - 29
			mat stars_tmfe_`ind'_`lhs'2[`x',1] = ///
			(abs(rtable[`k',3]) > invttail(`e(df_r)',0.10/2)) + ///
			(abs(rtable[`k',3]) > invttail(`e(df_r)',0.05/2)) + ///
			(abs(rtable[`k',3]) > invttail(`e(df_r)',0.01/2))
		}
		mat stars_tmfe_`ind'_`lhs' = stars_tmfe_`ind'_`lhs'\stars_tmfe_`ind'_`lhs'2
			
		* Append matrices and tables
		if "`lhs'" == "emp" {
			mat tmfe_`ind' = tmfe_`ind'_emp
			mat stars_tmfe_`ind' = stars_tmfe_`ind'_emp
		}
		if "`lhs'" != "emp" {
			mat tmfe_`ind' = [tmfe_`ind']\[tmfe_`ind'_`lhs']
			mat stars_tmfe_`ind' = [stars_tmfe_`ind']\[stars_tmfe_`ind'_`lhs']
		}

		* Create titles for tables
		if "`ind'" == "10" {
			local titname "Aggregate"
			local mer ""
		}
		if "`ind'" == "23" {
			local titname "Construction"
			local mer "merge"
		}
		if "`ind'" == "44" {
			local titname "Retail"
			local mer "merge"
		}
		if "`ind'" == "72" {
			local titname "Hospitality"
			local mer "merge"
		}
		
		* Create tables
		local columnn "`titname'"
		
		* Make the tables
		#delimit ;
			frmttable using "$prdir/out/analysis/cz_7400/tables/DD/pretrendtest_sc_regressions", replace
			tex statmat(tmfe_`ind') substat(1) sdec(4) annotate(stars_tmfe_`ind') asymbol(*,**,***)
			title("Regression-based pre-trend tests""Estimated TEs of Hurricane Maria on Orlando (employment and earnings")
			ctitles("","`columnn'")
			rtitles("2014 Q1 \& Q2 "\""\"Q4 \& Q3 "\""\"2015 Q1 \& Q2"\""\"Q3 \& Q4"\""\"2016 Q1 \& Q2"\""\"Q3 \& Q4"\""\"2017 Q1 \& Q2"\""\"2018 Q1 \& Q2"\""\"Q3"\""\"2014 Q1 \& Q2 "\""\"Q4 \& Q3 "\""\"2015 Q1 \& Q2"\""\"Q3 \& Q4"\""\"2016 Q1 \& Q2"\""\"Q3 \& Q4"\""\"2017 Q1 \& Q2"\""\"2018 Q1 \& Q2"\""\"Q3"\"") `mer' ;
		#delimit cr
	}
}


* Close the log file
log close sublog
