capture log close sublog
log using "$prdir/log/analysis/qcew/oth_alt_p_values.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Calcuate Chernozhukov, Wuthrich, and Zhu moving-block p-values 
* for last event-year, for the ATT estimates
* Author: Justin Wiltshire
	
* Updated: September 27, 2021
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* Chernozhukov, Wuthrich, and Zhu moving-block p-values, 5 most-treated CZs
*-------------------------------------------------------------------------------

tempfile core
di "ATT CWZ Moving Block p-values"
foreach ind in 10 23 44 72 {
	foreach v in emp avg_wkly_wage estabs {

		* Load the synthetic control weights
		qui use "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/resid_ln_`v'/average/sc_app_wt_avg.dta", clear
			
		* Prepare the data
		qui drop if mi(_Y_treated)
		rename _time tm
		qui keep tr_effect tm
				
		* Set trperiod local
		if "`v'" == "emp" {
			local tp = 692
		}
		if "`v'" != "emp" {
			local tp = 691
		}
				
		* Set up the data
		qui gen x = _n if tm >= `tp'
		qui egen xx = min(x)
		qui replace x = x - xx
		qui gen y = _n if tm < `tp'
		qui egen yy = max(y)
		qui replace y = y - yy - 1
		qui replace x = y if mi(x)
		qui rename x evt_year
		qui drop xx y yy
		qui sum evt_year
		local rmax = r(max)
		local rmin = r(min)
		local max1 = `rmax' + 1
		qui drop tm
		qui rename evt_year permuted_final_evt_year
			
		* Loop through the event periods
		tempfile core2
		forval e = `rmax'(-1)`rmin' {
			di "Permuted final event year `e', `v', `ind'"
			if `e' != `rmax' {
				qui use "`core2'", clear
				replace permuted_final_evt_year = permuted_final_evt_year + 1
				recode permuted_final_evt_year (`max1'=`rmin')
			}
			sort permuted_final_evt_year
			qui save "`core2'", replace
			
			* Generate the test statistic
			qui distinct permuted_final_evt_year if permuted_final_evt_year >= 0
			local rN = r(N)
			qui egen x = total(abs(tr_effect)) if inrange(permuted_final_evt_year, 0, `rmax')
			qui gen s = x/`rN'
			qui drop x
					
			* Keep only (permuted) event year rmax and recode with actual event year
			qui keep if permuted_final_evt_year == `rmax'
			qui gen evt_year = `e'
					
			* Comfirm directory exists, and save
			qui capture mkdir "$prdir/dta/analysis/qcew/moving_block_pval"
			qui capture mkdir "$prdir/dta/analysis/qcew/moving_block_pval/att"
			qui compress
			if `e' != `rmax' {
				qui append using "$prdir/dta/analysis/qcew/moving_block_pval/att/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta"
			}
			qui save "$prdir/dta/analysis/qcew/moving_block_pval/att/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta", replace

			* Drop x & s for next loop
			qui drop s evt_year
		}
				
		* Calculate p-values
		qui use "$prdir/dta/analysis/qcew/moving_block_pval/att/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta", clear
		qui drop permuted_final_evt_year
		order evt_year tr_effect s
		qui distinct evt_year if evt_year != `rmax'
		local eN = r(N)
		qui sort s
		qui gen rank = _n - 1
		qui gen f = rank/`eN'
		qui gen p = 1 - f
				
		* Keep event year rmax and save
		qui keep if evt_year == `rmax'
		qui compress
		qui save "$prdir/dta/analysis/qcew/moving_block_pval/att/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta", replace
	}
}

*-------------------------------------------------------------------------------
* Chernozhukov, Wuthrich, and Zhu moving-block p-values, three most-treated CZs
*-------------------------------------------------------------------------------

tempfile core
di "ATT CWZ Moving Block p-values"
foreach ind in 10 23 44 72 {
	foreach v in emp avg_wkly_wage estabs {

		* Load the synthetic control weights
		qui use "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/resid_ln_`v'/average3/sc_app_wt_avg.dta", clear
			
		* Prepare the data
		qui drop if mi(_Y_treated)
		rename _time tm
		qui keep tr_effect tm
				
		* Set trperiod local
		if "`v'" == "emp" {
			local tp = 692
		}
		if "`v'" != "emp" {
			local tp = 691
		}
				
		* Set up the data
		qui gen x = _n if tm >= `tp'
		qui egen xx = min(x)
		qui replace x = x - xx
		qui gen y = _n if tm < `tp'
		qui egen yy = max(y)
		qui replace y = y - yy - 1
		qui replace x = y if mi(x)
		qui rename x evt_year
		qui drop xx y yy
		qui sum evt_year
		local rmax = r(max)
		local rmin = r(min)
		local max1 = `rmax' + 1
		qui drop tm
		qui rename evt_year permuted_final_evt_year
			
		* Loop through the event periods
		tempfile core2
		forval e = `rmax'(-1)`rmin' {
			di "Permuted final event year `e', `v', `ind'"
			if `e' != `rmax' {
				qui use "`core2'", clear
				replace permuted_final_evt_year = permuted_final_evt_year + 1
				recode permuted_final_evt_year (`max1'=`rmin')
			}
			sort permuted_final_evt_year
			qui save "`core2'", replace
			
			* Generate the test statistic
			qui distinct permuted_final_evt_year if permuted_final_evt_year >= 0
			local rN = r(N)
			qui egen x = total(abs(tr_effect)) if inrange(permuted_final_evt_year, 0, `rmax')
			qui gen s = x/`rN'
			qui drop x
					
			* Keep only (permuted) event year rmax and recode with actual event year
			qui keep if permuted_final_evt_year == `rmax'
			qui gen evt_year = `e'
					
			* Comfirm directory exists, and save
			qui capture mkdir "$prdir/dta/analysis/qcew/moving_block_pval"
			qui capture mkdir "$prdir/dta/analysis/qcew/moving_block_pval/att3"
			qui compress
			if `e' != `rmax' {
				qui append using "$prdir/dta/analysis/qcew/moving_block_pval/att3/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta"
			}
			qui save "$prdir/dta/analysis/qcew/moving_block_pval/att3/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta", replace

			* Drop x & s for next loop
			qui drop s evt_year
		}
				
		* Calculate p-values
		qui use "$prdir/dta/analysis/qcew/moving_block_pval/att3/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta", clear
		qui drop permuted_final_evt_year
		order evt_year tr_effect s
		qui distinct evt_year if evt_year != `rmax'
		local eN = r(N)
		qui sort s
		qui gen rank = _n - 1
		qui gen f = rank/`eN'
		qui gen p = 1 - f
				
		* Keep event year rmax and save
		qui keep if evt_year == `rmax'
		qui compress
		qui save "$prdir/dta/analysis/qcew/moving_block_pval/att3/resid_ln_`v'_ind`ind'_event_year_`rmax'.dta", replace
	}
}

* Close the log
log close sublog
