capture log close sublog
log using "$prdir/log/analysis/qcew/sample_placebo_averages.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Create a sample of placebo averages for the empirical dist'n, top
* five and top three most-treated CZs (and also top 10. Top 10 estimation is
* effective for resid_ln_emp only, and not for hospitality because of CZ 7800, 
* but code for that run is set up for speed and is otherwise not complete
*
* Author: Justin Wiltshire
*
* Updated: May 6, 2021
*-------------------------------------------------------------------------------

* Set the number of placebo averages for the empirical distribution
local avgs = 1000

*** Top five treated CZs

* Loop over the variables of interest
di "Loop over the variables of interest"
#delimit ;
	foreach v in 
		resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs { ;
	#delimit cr
	foreach ind of numlist 10 23 44 72 {
		* Set the seed
		qui set seed 12345
		
		* Get placebo CZ list
		foreach c in 7400 $other_treated_cz {
			local filelist: dir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`v'/top5" files "*.dta"
			local n`ind'_placebos ""
			foreach f in `filelist' {

				* Observe the industry
				local naics = substr("`f'", 2, 2)
				
				* Get rid of the filetype suffix
				local f = subinstr("`f'", ".dta", "", .)
				
				* Observe placebo CZ if not from estimates beginning before 2014
				local cz ""
				if substr("`f'", -5, .) != "_2012" & substr("`f'", -5, .) != "_2013" {
				
					* Observe the placebo CZ
					local cz = substr("`f'", 7, .)
				}
				
				* Add to macro if correct NAICS code
				if "`naics'" == "`ind'" {
					local n`ind'_placebos "`n`ind'_placebos' `cz'"
				}
			}
			
			* Create list files to sample from
			clear
			local obsct : word count `n`ind'_placebos'
			set obs `obsct'
			qui gen donors = .
			forval n = 1/`obsct' {
				qui gettoken czn n`ind'_placebos : n`ind'_placebos
				qui replace donors = `czn' if _n == `n'
			}
			if `c' == 7400 {
				qui save "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`v'/czlist_n`ind'.dta", replace
			}
			if `c' != 7400 {
				qui save "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/`v'/czlist_`c'.dta", replace
			}
		}
		
		* Add the elements to each sample average
		local avgs_1 = `avgs' - 1
		forval n = 1/`avgs' {
			local samp_`n' ""
			local counter = 0
			foreach c in 7400 $other_treated_cz {
			
				/* Randomly select c
				clear
				qui set obs 5
				local cx 7400 $other_treated_cz
				qui gen cz = .
				forval m = 1/5 {
					qui gettoken czn cx : cx
					qui replace cz = `czn' if _n == `m'
				}
				qui gen p = runiform()
				qui sort p
				qui sum cz if _n == 1
				local c = r(mean)*/
				
				* Get per-capita FEMA applications for c
				* Load the FEMA data
				qui use "$prdir/cw/geo/dta/cty_cz/cln/fema_cz.dta", clear
					
				* Sort the FEMA applications
				qui sum pc_fema_apps if cz == `c'
				local wt = r(mean)
				
				* Randomly select the donor county to add to the average
				if `c' == 7400 {
					qui use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`v'/czlist_n`ind'.dta", clear
				}
				if `c' != 7400 {
					qui use "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/`v'/czlist_`c'.dta", clear
				}
				qui keep donors
					
				* Assign numbers from a uniform distribution
				qui gen p = runiform()
					
				* Sort on p and draw the donor county associated with the smallest p
				qui sort p
				qui sum donors if _n == 1
				local donor = r(mean)
					
				* Ensure necessary folders exist
				qui capture mkdir "$prdir/dta/analysis/qcew/placebo_averages"
				qui capture mkdir "$prdir/dta/analysis/qcew/placebo_averages/`v'"
				qui capture mkdir "$prdir/dta/analysis/qcew/placebo_averages/`v'/`ind'"
				qui capture mkdir "$prdir/dta/analysis/qcew/distribution"
				qui capture mkdir "$prdir/dta/analysis/qcew/distribution/`v'"
				qui capture mkdir "$prdir/dta/analysis/qcew/distribution/`v'/`ind'"
					
				* Use the placebo TE associated with this donor and this treated county to this average
				qui use "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`v'/top5/n`ind'_cz`donor'.dta", clear
									
				* Generate and keep only variables of interest
				qui keep _time _Y_synthetic _Y_treated
				qui gen wt = `wt'
				qui gen counter = `counter'
				qui gen donorid = "tr_`c'_p_`donor'"
					
				* Save or append and save
				di "Add the placebo run for LHS variable `v', industry `ind', donor `donor' for treated `c', to sample `n' of a total `avgs', to be averaged"
				if `counter' > 0 {
					qui append using "$prdir/dta/analysis/qcew/placebo_averages/`v'/`ind'/placebo_average_`n'.dta"
				}
				qui save "$prdir/dta/analysis/qcew/placebo_averages/`v'/`ind'/placebo_average_`n'.dta", replace
				local counter = `counter' + 1
			}
		}

		* Mean-collapse each sample, and save
		forval n = 1(1)`avgs' {
			
			* Load the data
			qui use "$prdir/dta/analysis/qcew/placebo_averages/`v'/`ind'/placebo_average_`n'.dta", clear
			
			* Collapse by event year and estimate
			collapse (mean) _Y_treated _Y_synthetic [aw=wt], by(_time)
			
			* Calculate the ATE
			qui gen tr_effect = _Y_treated - _Y_synthetic
			
			* Indicate placebo
			qui gen placebo_id = `n'
					
			* Compress and save
			qui compress
			qui save "$prdir/dta/analysis/qcew/placebo_averages/`v'/`ind'/placebo_average_`n'.dta", replace
		}
		
		* Put the averages in a single file, along with the ATE, and save
		qui use "$prdir/dta/analysis/qcew/placebo_averages/`v'/`ind'/placebo_average_1.dta"
		forval n = 2(1)`avgs' {
			qui append using "$prdir/dta/analysis/qcew/placebo_averages/`v'/`ind'/placebo_average_`n'.dta"
		}
		
		* Append the ATE and code the placebo dummy
		qui append using "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/`v'/average/sc_app_wt_avg.dta"
		
		* Code the placebo dummy then calculate the RMSPE
		qui drop if mi(_time)
		qui recode placebo (.=0)
		qui bysort placebo_id: egen x = total(tr^2) if _time >= 692
		qui distinct _time if _time >= 692
		qui replace x = x/r(ndistinct)
		qui bysort placebo_id: egen y = total(tr^2) if _time < 692
		qui distinct _time if _time < 692
		qui replace y = y/r(ndistinct)
		qui bysort placebo_id: egen mspe_post = max(x)
		qui bysort placebo_id: egen mspe_pre = max(y)
		qui gen rmspe = mspe_post/mspe_pre
		qui sort _time rmspe
		qui drop x y mspe*
		rename _time time
		
		* Calculate the RMSPE p-value
		gsort time -rmspe
		bysort time: gen rank = _n
		gen pval = rank/1001
		
		* Compress and save
		qui compress
		qui save "$prdir/dta/analysis/qcew/distribution/`v'/`ind'/distn_n`avgs'.dta", replace
	}
}

*** Top three treated CZs

* Loop over the variables of interest
di "Loop over the variables of interest"
#delimit ;
	foreach v in 
		resid_ln_emp resid_ln_avg_wkly_wage resid_ln_estabs { ;
	#delimit cr
	foreach ind of numlist 10 23 44 72 {
		* Set the seed
		qui set seed 12345
		
		* Get placebo CZ list
		foreach c in 7400 $top3_treated_cz {
			local filelist: dir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`v'/top3" files "*.dta"
			local n`ind'_placebos ""
			foreach f in `filelist' {

				* Observe the industry
				local naics = substr("`f'", 2, 2)
				
				* Get rid of the filetype suffix
				local f = subinstr("`f'", ".dta", "", .)
				
				* Observe placebo CZ if not from estimates beginning before 2014
				local cz ""
				if substr("`f'", -5, .) != "_2012" & substr("`f'", -5, .) != "_2013" {
				
					* Observe the placebo CZ
					local cz = substr("`f'", 7, .)
				}
				
				* Add to macro if correct NAICS code
				if "`naics'" == "`ind'" {
					local n`ind'_placebos "`n`ind'_placebos' `cz'"
				}
			}
			
			* Create list files to sample from
			clear
			local obsct : word count `n`ind'_placebos'
			set obs `obsct'
			qui gen donors = .
			forval n = 1/`obsct' {
				qui gettoken czn n`ind'_placebos : n`ind'_placebos
				qui replace donors = `czn' if _n == `n'
			}
			if `c' == 7400 {
				qui save "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`v'/czlist_n`ind'.dta", replace
			}
			if `c' != 7400 {
				qui save "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/`v'/czlist_`c'.dta", replace
			}
		}
		
		* Add the elements to each sample average
		local avgs_1 = `avgs' - 1
		forval n = 1/`avgs' {
			local samp_`n' ""
			local counter = 0
			foreach c in 7400 $top3_treated_cz {
			
				* Get per-capita FEMA applications for c
				* Load the FEMA data
				qui use "$prdir/cw/geo/dta/cty_cz/cln/fema_cz.dta", clear
					
				* Sort the FEMA applications
				qui sum pc_fema_apps if cz == `c'
				local wt = r(mean)
				
				* Randomly select the donor county to add to the average
				if `c' == 7400 {
					qui use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`v'/czlist_n`ind'.dta", clear
				}
				if `c' != 7400 {
					qui use "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/`v'/czlist_`c'.dta", clear
				}
				qui keep donors
					
				* Assign numbers from a uniform distribution
				qui gen p = runiform()
					
				* Sort on p and draw the donor county associated with the smallest p
				qui sort p
				qui sum donors if _n == 1
				local donor = r(mean)
					
				* Ensure necessary folders exist
				qui capture mkdir "$prdir/dta/analysis/qcew/placebo_averages/3top"
				qui capture mkdir "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'"
				qui capture mkdir "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'/`ind'"
				qui capture mkdir "$prdir/dta/analysis/qcew/distribution/3top"
				qui capture mkdir "$prdir/dta/analysis/qcew/distribution/3top/`v'"
				qui capture mkdir "$prdir/dta/analysis/qcew/distribution/3top/`v'/`ind'"
					
				* Use the placebo TE associated with this donor and this treated county to this average
				qui use "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`v'/top3/n`ind'_cz`donor'.dta", clear
									
				* Generate and keep only variables of interest
				qui keep _time _Y_synthetic _Y_treated
				qui gen wt = `wt'
				qui gen counter = `counter'
				qui gen donorid = "tr_`c'_p_`donor'"
					
				* Save or append and save
				di "Add the placebo run for LHS variable `v', industry `ind', donor `donor' for treated `c', to sample `n' of a total `avgs', to be averaged"
				if `counter' > 0 {
					qui append using "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'/`ind'/placebo_average_`n'.dta"
				}
				qui save "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'/`ind'/placebo_average_`n'.dta", replace
				local counter = `counter' + 1
			}
		}

		* Mean-collapse each sample, and save
		forval n = 1(1)`avgs' {
			
			* Load the data
			qui use "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'/`ind'/placebo_average_`n'.dta", clear
			
			* Collapse by event year and estimate
			collapse (mean) _Y_treated _Y_synthetic [aw=wt], by(_time)
			
			* Calculate the ATE
			qui gen tr_effect = _Y_treated - _Y_synthetic
			
			* Indicate placebo
			qui gen placebo_id = `n'
					
			* Compress and save
			qui compress
			qui save "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'/`ind'/placebo_average_`n'.dta", replace
		}
		
		* Put the averages in a single file, along with the ATE, and save
		qui use "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'/`ind'/placebo_average_1.dta"
		forval n = 2(1)`avgs' {
			qui append using "$prdir/dta/analysis/qcew/placebo_averages/3top/`v'/`ind'/placebo_average_`n'.dta"
		}
		
		* Append the ATE and code the placebo dummy
		qui append using "$prdir/dta/analysis/qcew/sc_results_dta/avg_oth_treat/`ind'/`v'/average3/sc_app_wt_avg.dta"
		
		* Code the placebo dummy then calculate the RMSPE
		qui drop if mi(_time)
		qui recode placebo (.=0)
		qui bysort placebo_id: egen x = total(tr^2) if _time >= 692
		qui distinct _time if _time >= 692
		qui replace x = x/r(ndistinct)
		qui bysort placebo_id: egen y = total(tr^2) if _time < 692
		qui distinct _time if _time < 692
		qui replace y = y/r(ndistinct)
		qui bysort placebo_id: egen mspe_post = max(x)
		qui bysort placebo_id: egen mspe_pre = max(y)
		qui gen rmspe = mspe_post/mspe_pre
		qui sort _time rmspe
		qui drop x y mspe*
		rename _time time
		
		* Calculate the RMSPE p-value
		gsort time -rmspe
		bysort time: gen rank = _n
		gen pval = rank/1001
		
		* Compress and save
		qui compress
		qui save "$prdir/dta/analysis/qcew/distribution/3top/`v'/`ind'/distn_n`avgs'.dta", replace
	}
}	
	
* Close log file
log close sublog
