capture log close sublog
log using "$prdir/log/analysis/qcew/oth_tables.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Inference and tables for the Orlando estimated effects
* Author: Justin Wiltshire
	
* Updated: January 7, 2021
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* Calculate the values of interest
*-------------------------------------------------------------------------------

* Top 5 treated CZs

* Set up the loop for the outcome variables
foreach v in ln_emp ln_avg_wkly_wage ln_estabs {

	* Loop over selected NAICS supersectors and variables of interest
	foreach ind of numlist 10 23 44 72 {
		local z = 12

		* Define the industry labels
		if "`ind'" == "10" {
			local industry "Total"
			local industry2 ""
		}
		else if "`ind'" == "23" {
			local industry "Construction"
			local industry2 ""
		}
		else if "`ind'" == "44" {
			local industry "Retail"
			local industry2 ""
		}
		else if "`ind'" == "72" {
			local industry "Accommodation \&"
			local industry2 "Food Services"
		}
		
		* Load the data			
		qui use "$prdir/dta/analysis/qcew/distribution/resid_`v'/`ind'/distn_n1000.dta", clear
							
		* Put the key figures in a matrix
		qui sum time, d
		local tmax = r(max)
		qui sum tr_effect if placebo_id == 0 & time == `tmax', d
		mat effect`ind'_`z'month = r(mean)
		qui sum rmspe if placebo_id == 0 & time == `tmax', d
		mat mspe_ratio`ind'_`z'month = r(mean)
		qui sum pval if placebo_id == 0 & time == `tmax', d
		mat mspe_pval`ind'_`z'month = r(mean)
		mat mspe_stars`ind'_`z'month = (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
			
		* CWZ p-values
		if "`v'" == "ln_emp" {
			local e = 12
		}
		if "`v'" != "ln_emp" {
			local e = 4
		}
		
		* Load the CWZ moving block test data
		qui use "$prdir/dta/analysis/qcew/moving_block_pval/att/resid_`v'_ind`ind'_event_year_`e'.dta", clear
							
		* Put the p-values in a matrix
		qui sum p, d
		mat cwz_p_`ind'_`z'month = r(mean)
					
		* Combine these matrices across12-month estimates and LHS variables
		di "Combine matrices, `v', ind `ind'"
		if "`v'" == "ln_emp" {
			mat effect`ind' = effect`ind'_`z'month
			mat mspe_ratio`ind' = mspe_ratio`ind'_`z'month
			mat mspe_pval`ind' = mspe_pval`ind'_`z'month
			mat cwz_p_`ind' = cwz_p_`ind'_`z'month
			mat mspe_stars`ind' = mspe_stars`ind'_`z'month
		}
		else if "`v'" != "ln_emp" {
			mat effect`ind' = effect`ind', effect`ind'_`z'month
			mat mspe_ratio`ind' = mspe_ratio`ind', mspe_ratio`ind'_`z'month
			mat mspe_pval`ind' = mspe_pval`ind', mspe_pval`ind'_`z'month
			mat cwz_p_`ind' = cwz_p_`ind', cwz_p_`ind'_`z'month
			mat mspe_stars`ind' = mspe_stars`ind', mspe_stars`ind'_`z'month
		}	
			
		* Combine the matrices into one
		mat vals`ind' = effect`ind'
		mat mspevals`ind' = mspe_ratio`ind'\mspe_pval`ind'\cwz_p_`ind'
		
		* Confirm necessary folders exist
		qui capture mkdir "$prdir/out/analysis/att"
		qui capture mkdir "$prdir/out/analysis/att/tables"
		
		* Now make the tables *if* we've looped through to the last lhs variable (ln_estabs)
		if "`v'" == "ln_estabs" {
										
			* Make the combined tables
			frmttable using "$prdir/out/analysis/att/tables/top5_att_qcew_naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
			annotate(mspe_stars`ind') asymbol(*,**,***) ///
			ctitles("`industry'","Log","Log compensation","Log"\"`industry2'","employment","per worker","establishments"\"","12 month ATT","12 month ATT","12 month ATT") ///
			rtitles("Treatment effect")
						
			frmttable using "$prdir/out/analysis/att/tables/top5_att_qcew_naics_`ind'", replace tex statmat(mspevals`ind') sdec(4) ///
			rtitles("RMSPE"\"RMSPE \textit{p}-val"\"Moving block \textit{p}-val") append
		}
	}
}


* Top 3 treated CZs

* Set up the loop for the outcome variables
foreach v in ln_emp ln_avg_wkly_wage ln_estabs {

	* Loop over selected NAICS supersectors and variables of interest
	foreach ind of numlist 10 23 44 72 {
		local z = 12

		* Define the industry labels
		if "`ind'" == "10" {
			local industry "Total"
			local industry2 ""
		}
		else if "`ind'" == "23" {
			local industry "Construction"
			local industry2 ""
		}
		else if "`ind'" == "44" {
			local industry "Retail"
			local industry2 ""
		}
		else if "`ind'" == "72" {
			local industry "Accommodation \&"
			local industry2 "Food Services"
		}
		
		* Load the data			
		qui use "$prdir/dta/analysis/qcew/distribution/3top/resid_`v'/`ind'/distn_n1000.dta", clear
							
		* Put the key figures in a matrix
		qui sum time, d
		local tmax = r(max)
		qui sum tr_effect if placebo_id == 0 & time == `tmax', d
		mat effect`ind'_`z'month = r(mean)
		qui sum rmspe if placebo_id == 0 & time == `tmax', d
		mat mspe_ratio`ind'_`z'month = r(mean)
		qui sum pval if placebo_id == 0 & time == `tmax', d
		mat mspe_pval`ind'_`z'month = r(mean)
		mat mspe_stars`ind'_`z'month = (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
			
		* CWZ p-values
		if "`v'" == "ln_emp" {
			local e = 12
		}
		if "`v'" != "ln_emp" {
			local e = 4
		}
		
		* Load the CWZ moving block test data
		qui use "$prdir/dta/analysis/qcew/moving_block_pval/att3/resid_`v'_ind`ind'_event_year_`e'.dta", clear
							
		* Put the p-values in a matrix
		qui sum p, d
		mat cwz_p_`ind'_`z'month = r(mean)
					
		* Combine these matrices across12-month estimates and LHS variables
		di "Combine matrices, `v', ind `ind'"
		if "`v'" == "ln_emp" {
			mat effect`ind' = effect`ind'_`z'month
			mat mspe_ratio`ind' = mspe_ratio`ind'_`z'month
			mat mspe_pval`ind' = mspe_pval`ind'_`z'month
			mat cwz_p_`ind' = cwz_p_`ind'_`z'month
			mat mspe_stars`ind' = mspe_stars`ind'_`z'month
		}
		else if "`v'" != "ln_emp" {
			mat effect`ind' = effect`ind', effect`ind'_`z'month
			mat mspe_ratio`ind' = mspe_ratio`ind', mspe_ratio`ind'_`z'month
			mat mspe_pval`ind' = mspe_pval`ind', mspe_pval`ind'_`z'month
			mat cwz_p_`ind' = cwz_p_`ind', cwz_p_`ind'_`z'month
			mat mspe_stars`ind' = mspe_stars`ind', mspe_stars`ind'_`z'month
		}	
			
		* Combine the matrices into one
		mat vals`ind' = effect`ind'
		mat mspevals`ind' = mspe_ratio`ind'\mspe_pval`ind'\cwz_p_`ind'
		
		* Confirm necessary folders exist
		qui capture mkdir "$prdir/out/analysis/att"
		qui capture mkdir "$prdir/out/analysis/att/tables"
		
		* Now make the tables *if* we've looped through to the last lhs variable (ln_estabs)
		if "`v'" == "ln_estabs" {
										
			* Make the combined tables
			frmttable using "$prdir/out/analysis/att/tables/top3_att_qcew_naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
			annotate(mspe_stars`ind') asymbol(*,**,***) ///
			ctitles("`industry'","Log","Log compensation","Log"\"`industry2'","employment","per worker","establishments"\"","12 month ATT","12 month ATT","12 month ATT") ///
			rtitles("Treatment effect")
						
			frmttable using "$prdir/out/analysis/att/tables/top3_att_qcew_naics_`ind'", replace tex statmat(mspevals`ind') sdec(4) ///
			rtitles("RMSPE"\"RMSPE \textit{p}-val"\"Moving block \textit{p}-val") append
		}
	}
}
	
* Close the log file
log close sublog
