capture log close sublog
log using "$prdir/log/analysis/qcew/synth_ctrls.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Synthetic control analysis of deseasonalized 
* QCEW variables for the top5 and top 3 'treated' CZs (applications per capita)
* Author: Justin Wiltshire

* Updated: May 6, 2021
*-------------------------------------------------------------------------------

* Ensure necessary folder exists
qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/placebo_oth_treat"

* Loop over the other 'treated' CZs
foreach c of global top10_treated_cz {
	
	* Get per-capita FEMA applications as weights
	qui use "$prdir/cw/geo/dta/cty_cz/cln/fema_cz.dta", clear
		
	* Capture the weight as a macro
	qui keep if cz == `c'
	qui sum pc_fema_apps
	local awt = r(mean)
	
	* Load the cleaned and deseasonalized QCEW data
	qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
	  
	* Change settings for the synthetic control
	qui set matsize 800
	  
	* Exclude Orlando and all CZs with >= 0.0001 FEMA applications per capita from donor pool
	foreach z of numlist $cz_droplist {
		if "`c'" != "`z'" {
			drop if cz == `z' | cz== 7400
		}
	}
	
	* Ensure necessary folders exist
	qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/cz_`c'"
	qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/cz_`c'"

	* Keep for 2014 and later (after the recovery had firmly taken root)
	keep if year >= 2014 
	tempfile core
	save "`core'"
			
	* Run for selected NAICS supersectors
	foreach ind of numlist 10 23 44 72 {
		use "`core'", clear
		
				
		* Restrict the donor pool to CZs of appropriate size
		qui sum emp if naics == `ind', d
		keep if emp >= r(p75) & naics == `ind'
				
		* Keep the industry of interest  
		keep if naics == `ind'
			  
		* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
		bysort cz: egen ct = count(ln_emp)
		qui sum ct, d
		qui gen rmax = r(max)
		qui sum ct if cz == `c', d
		if r(N) == rmax {
			keep if ct == rmax
					
			* Set up and run the synthetic control estimations
			tsset cz tm
			
			* Synthetic control for each of the LHS variables
			foreach lhs of varlist resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
				if "`lhs'" == "resid_ln_emp" {
					local emp_qtr "`lhs'(691)"
					local trperiod = 692
					local last_pretreat = 691
				}
				else if "`lhs'" != "resid_ln_emp" {
					local emp_qtr ""
					
					* Non-employment variables are only observed quarterly
					keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
					local trperiod = 691
					local last_pretreat = 688
				}
				
				* Ensure necessary folders exist
				qui capture mkdir "$prdir/out/analysis/cz_`c'/naics_`ind'"
				qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/cz_`c'/`lhs'"
				qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'"
				qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'"
				
				* Note the particular run
				di "Treated CZ `c'; NAICS `ind'; LHS `lhs'"
				
				#delimit ;
					qui synth 
						`lhs' `emp_qtr' `lhs'(688) `lhs'(685) `lhs'(682) `lhs'(679) `lhs'(676) `lhs'(673) `lhs'(661) `lhs'(655) `lhs'(649)
						prop_emp_23(649(3)`last_pretreat') prop_emp_72(649(3)`last_pretreat'), trunit(`c') trperiod(`trperiod') fig 
						keep("$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/sc_trunit_`c'.dta") replace;
					#delimit cr 
				preserve
				
				* Merge in the weights
				qui use "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/sc_trunit_`c'.dta", clear
				qui gen app_wt = `awt'
				qui save "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/sc_trunit_`c'.dta", replace			  
				restore
			}
		}
	}
}

* Get per-capita FEMA applications as weights
qui use "$prdir/cw/geo/dta/cty_cz/cln/fema_cz.dta", clear
	
* Capture the weight as a macro
qui keep if cz == 7400
qui sum pc_fema_apps
local awt = r(mean)

*** Top five treated CZs

* Load and append the data
foreach ind of numlist 10 23 44 72 {
	foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
	
		* Get the complete set of .dta files
		local filelist: dir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/" files "*.dta"
		di "Filelist:" `filelist'
				
		* Load and append the data
		qui use "$prdir/dta/analysis/qcew/sc_results_dta`donors'/cz_7400/`lhs'/deseasonalize_n`ind'.dta", clear
		qui gen app_wt = `awt'
		foreach c in `filelist' {
			append using "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/`c'"
		}
		
		* Collapse by event year
		collapse (mean) _Y_treated _Y_synthetic [aweight=app_wt], by(_time)

		* Calculate the treatment effect
		qui gen tr_effect = _Y_treated - _Y_synthetic
			
		* Save
		qui compress
		qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/average"
		qui save "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/average/sc_app_wt_avg.dta", replace
	}
}

*** Top three treated CZs

* Load and append the data
foreach ind of numlist 10 23 44 72 {
	foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_estabs {
	
		* Load and append the data
		qui use "$prdir/dta/analysis/qcew/sc_results_dta`donors'/cz_7400/`lhs'/deseasonalize_n`ind'.dta", clear
		qui gen app_wt = `awt'
		foreach c of global top3_treated_cz {
			di `c'
			append using "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/sc_trunit_`c'"
		}
		
		* Collapse by event year
		collapse (mean) _Y_treated _Y_synthetic [aweight=app_wt], by(_time)

		* Calculate the treatment effect
		qui gen tr_effect = _Y_treated - _Y_synthetic
			
		* Save
		qui compress
		qui capture mkdir "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/average3"
		qui save "$prdir/dta/analysis/qcew/sc_results_dta`donors'/avg_oth_treat/`ind'/`lhs'/average3/sc_app_wt_avg.dta", replace
	}
}
	
* Close the log file
log close sublog
