capture log close sublog
log using "$prdir/log/analysis/qcew/synth_ctrls.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Synthetic control analysis of deseasonalized 
* QCEW variables, by CZ
* Author: Justin Wiltshire

* Updated: September 27, 2021
*-------------------------------------------------------------------------------

* Set the treated unit
forval c = 7400(200)7600 {
 
	* Load the cleaned and deseasonalized QCEW data
	qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
	  
	* Change settings for the synthetic control
	qui set matsize 11000
	  
	* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
	foreach z of numlist $cz_droplist {
		if "`c'" != "`z'" {
			drop if cz == `z'
		}
	}
	if "`c'" == "7600" {
		drop if cz == 7400
	}

	* Keep for 2014 and later (after the recovery had firmly taken root)
	keep if year >= 2014 
	tempfile core
	save "`core'"
			
	* Run for selected NAICS supersectors
	foreach ind of numlist 10 23 44 72 {
		if `c' == 7400 | (`c' == 7600 & inlist(`ind', 10, 23)) {
			use "`core'", clear
			local pdflist_`ind'
					
			* Restrict the donor pool to CZs of appropriate size
			qui sum emp if naics == `ind', d
			keep if emp >= r(p75) & naics == `ind'
					
			* Keep the industry of interest  
			keep if naics == `ind'
				  
			* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
			bysort cz: egen ct = count(ln_emp)
			qui sum ct, d
			qui gen rmax = r(max)
			qui sum ct if cz == `c', d
			if r(N) == rmax {
				keep if ct == rmax
						
				* Set up and run the synthetic control estimations
				tsset cz tm
				
				* Synthetic control for each of the LHS variables
				foreach lhs of varlist resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
					if "`lhs'" == "resid_ln_emp" {
						local emp_qtr "`lhs'(691)"
						local trperiod = 692
						local last_pretreat = 691
					}
					else if "`lhs'" != "resid_ln_emp" {
						local emp_qtr ""
						
						* Non-employment variables are only observed quarterly
						keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
						local trperiod = 691
						local last_pretreat = 688
					}
					
					* Note the particular run
					di "Treated CZ `c'; NAICS `ind'; LHS `lhs'"
				
					#delimit ;
						qui synth 
							`lhs' `emp_qtr' `lhs'(688) `lhs'(685) `lhs'(682) `lhs'(679) `lhs'(676) `lhs'(673) `lhs'(661) `lhs'(655) `lhs'(649)
							prop_emp_23(649(3)`last_pretreat') prop_emp_72(649(3)`last_pretreat'), trunit(`c') trperiod(`trperiod') fig 
							keep("$prdir/dta/analysis/qcew/sc_results_dta/cz_`c'/`lhs'/deseasonalize_n`ind'.dta") replace;
						#delimit cr 
									  
					tempfile g`ind'
					nicepdf "`g`ind''.pdf"
					local pdflist_`ind' "`pdflist_`ind'' `g`ind''.pdf"
				}
				
				* The below only works if running on a Unix system. Comment it out if running on anything else
				combine_pdfs `pdflist_`ind'' using "$prdir/out/analysis/cz_`c'/naics_`ind'/sc_deseasonalize_n_`ind'_cz`c'_yr_hole.pdf", replace
			}
		}
	}
}
	
* Close the log file
log close sublog
