capture log close sublog
log using "$prdir/log/analysis/qcew/tables.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Inference and tables for the Orlando estimated effects
* Author: Justin Wiltshire
	
* Updated: September 27, 2021
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* Calculate the values of interest
*-------------------------------------------------------------------------------

* Loop over selected NAICS supersectors and variables of interest
foreach ind of numlist 10 23 44 72 {
		 
	* Set up the loop for the outcome variables
	foreach lhs in ln_emp ln_avg_wkly_wage ln_estabs {
			
		* Set up the loop to yield six- and twelve-month impacts
		forval m = 0(6)6 {
			local z = `m' + 6
				
			* Load the data
			use "$prdir/dta/analysis/qcew/sc_merged/cz_7400/resid_`lhs'/deseasonalize_n`ind'_merged.dta", clear
						
			* Calculate the MSPE ratio and rank CZs
			if "`lhs'" == "ln_emp" {
							
				* Rename the Orlando TE
				rename tr_effect_orl tr_effect_7400

				* Reshape the data
				qui reshape long tr_effect_, i(_time) j(cz)
				sort cz _time
								
				* Generate the MSPE ratio
				qui gen mspe_pre = .
				qui gen mspe_post`z'month = .
				qui distinct _time
				local post_periods = `z'
				local last_p = 692 + `z'
				levelsof(cz), local(cz)
				foreach c of local cz {
					egen mspe_pre_`c' = total(tr_effect^2) if cz == `c' & _time < 692
					replace mspe_pre = mspe_pre_`c'/44 if cz == `c'
					egen mspe_post`z'month_`c' = total(tr_effect^2) if cz == `c' & inrange(_time, 692, `last_p')
					replace mspe_post`z'month = mspe_post`z'month_`c'/`post_periods' if cz == `c'
					drop mspe_pre_`c' mspe_post`z'month_`c'
				}
				bysort cz (mspe_pre): replace mspe_pre = mspe_pre[1]
				bysort cz (mspe_post`z'month): replace mspe_post`z'month = mspe_post`z'month[1]
				qui gen ratio`z'month = mspe_post`z'month/mspe_pre
				qui keep if _time == `last_p'
			}
			else if "`lhs'" != "ln_emp" {
						
				* Rename the Orlando TE
				rename tr_effect_orl tr_effect_7400

				* Reshape the data
				qui reshape long tr_effect_, i(time) j(cz)
				sort cz time
										
				* Generate the MSPE ratio
				qui gen mspe_pre = .
				qui gen mspe_post`z'month = .
				qui distinct _time
				if `m' == 0 {
					local k = 2
				}
				else if `m' == 6 {
					local k = 4
				}
				local post_periods = `k'
				local last_p = 230 + `k'
				levelsof(cz), local(cz)
				foreach c of local cz {
					egen mspe_pre_`c' = total(tr_effect^2) if cz == `c' & time < 230
					replace mspe_pre = mspe_pre_`c'/14 if cz == `c'
					egen mspe_post`z'month_`c' = total(tr_effect^2) if cz == `c' & inrange(time, 230, `last_p')
					replace mspe_post`z'month = mspe_post`z'month_`c'/`post_periods' if cz == `c'
					drop mspe_pre_`c' mspe_post`z'month_`c'
				}
				bysort cz (mspe_pre): replace mspe_pre = mspe_pre[1]
				bysort cz (mspe_post`z'month): replace mspe_post`z'month = mspe_post`z'month[1]
				qui gen ratio`z'month = mspe_post`z'month/mspe_pre
				qui keep if time == `last_p'
			}
									
			* Keep only variables we want
			keep cz tr_effect ratio*
								
			* Get the number of placebo CZs
			local j = _N - 1
			qui gen donor_sample_size = `j'

			* Generate the Orlando ranking
			sort ratio`z'month
			qui gen rank_ratio`z'month = _n
									
			* Keep only the relevant observation
			keep if cz == 7400

			* Generate the p-values
			qui gen p_value_ratio`z'month = (1 + `j' + 1 - rank_ratio`z'month)/(`j' + 1)
									
			* Keep variables of interest and merge with the other pseudo p-value data
			keep cz tr_effect ratio* rank donor_sample_size p_value*
			compress
			save "$prdir/dta/analysis/qcew/sc_pvalue/cz_7400/resid_`lhs'/p_values_n`ind'_month`z'.dta", replace
		}
	}
}


*-------------------------------------------------------------------------------
* Make the individual tables
*-------------------------------------------------------------------------------

* Loop over six- and twelve-month impacts
forval z = 6(6)12 {

	* Loop over the LHS variables
	foreach lhs in ln_emp ln_avg_wkly_wage ln_estabs {
				 
		* Loop over the NAICS supersectors
		foreach ind of numlist 10 23 44 72 {
					
			* Define the industry labels
			if "`ind'" == "10" {
				local industry "Total"
				local industry2 ""
			}
			else if "`ind'" == "23" {
				local industry "Construction"
				local industry2 ""
			}
			else if "`ind'" == "44" {
				local industry "Retail"
				local industry2 ""
			}
			else if "`ind'" == "72" {
				local industry "Accommodation \&"
				local industry2 "Food Services"
			}
					
			* Load the data
			qui use "$prdir/dta/analysis/qcew/sc_pvalue/cz_7400/resid_`lhs'/p_values_n`ind'_month`z'.dta", clear
							
			* Put the key figures in a matrix
			if "`lhs'" == "ln_emp" {
				qui sum tr_effect, d
				mat effect`ind' = r(mean)
				qui sum ratio`z'month, d
				mat mspe_ratio`ind' = r(mean)
				qui sum p_value_ratio`z'month, d
				mat mspe_pval`ind' = r(mean)
				mat mspe_stars`ind' = (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
				qui sum donor_sample_size, d
				mat N`ind' = r(mean) + 1
			}	
			else if "`lhs'" != "ln_emp" {
				qui sum tr_effect, d
				mat effect`ind' = effect`ind', r(mean)
				qui sum ratio`z'month, d
				mat mspe_ratio`ind' = mspe_ratio`ind', r(mean)
				qui sum p_value_ratio`z'month, d
				mat mspe_pval`ind' = mspe_pval`ind', r(mean)
				mat mspe_stars`ind' = mspe_stars`ind', (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
				qui sum donor_sample_size, d
				mat N`ind' = N`ind', (r(mean) + 1)
			}
							
			* Now make the tables *if* we've looped through to the last lhs variable (ln_avg_wkly_wage)
			if "`lhs'" == "ln_estabs" {
				
				* Combine the matrices into one
				mat vals`ind' = effect`ind'
				mat mspevals`ind' = mspe_ratio`ind'\mspe_pval`ind'
						
				* Make the individual tables
				frmttable using "$prdir/out/analysis/cz_7400/tables/`z'_month/naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
				annotate(mspe_stars`ind') asymbol(*,**,***) ///
				ctitles("`industry'","Log","Log compensation","Log"\"`industry2'","employment","per worker","establishments") ///
				rtitles("Treatment effect")
				
				frmttable using "$prdir/out/analysis/cz_7400/tables/`z'_month/naics_`ind'", replace tex statmat(mspevals`ind') sdec(4) ///
				rtitles("RMSPE"\"RMSPE p-value") append
				
				frmttable using "$prdir/out/analysis/cz_7400/tables/`z'_month/naics_`ind'", replace tex statmat(N`ind') sdec(0) ///
				rtitles("N") append
			}
		}
	}
}

*-------------------------------------------------------------------------------
* Make the (residualized) combined tables
*-------------------------------------------------------------------------------

* Loop over the NAICS supersectors
foreach ind of numlist 10 23 44 72 {
			
	* Loop over the LHS variables
	foreach lhs in ln_emp ln_avg_wkly_wage ln_estabs {
				
		* Loop over six- and twelve-month impacts
		forval z = 6(6)12 {
					
			* Define the industry labels
			if "`ind'" == "10" {
				local industry "Total"
				local industry2 ""
			}
			else if "`ind'" == "23" {
				local industry "Construction"
				local industry2 ""
			}
			else if "`ind'" == "44" {
				local industry "Retail"
				local industry2 ""
			}
			else if "`ind'" == "72" {
				local industry "Accommodation \&"
				local industry2 "Food Services"
			}
									
			* Load the data
			qui use "$prdir/dta/analysis/qcew/sc_pvalue/cz_7400/resid_`lhs'/p_values_n`ind'_month`z'.dta", clear
							
			* Put the key figures in a matrix
			qui sum tr_effect, d
			mat effect`ind'_`z'month = r(mean)
			qui sum ratio`z'month, d
			mat mspe_ratio`ind'_`z'month = r(mean)
			qui sum p_value_ratio`z'month, d
			mat mspe_pval`ind'_`z'month = r(mean)
			mat mspe_stars`ind'_`z'month = (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
			qui sum donor_sample_size, d
			mat N`ind'_`z'month = r(mean) + 1
			
			* Andrews and CWZ p-values
			if "`lhs'" == "ln_emp" {
				local e = `z'
			}
			if "`lhs'" != "ln_emp" {
				local e = `z'/3
			}
			
			* Load the Andrews test data
			qui use "$prdir/dta/analysis/qcew/andrews_tests/resid_`lhs'_ind`ind'_event_year_`e'.dta", clear
							
			* Put the p-values in a matrix
			qui sum p, d
			mat andrews_p_`ind'_`z'month = r(mean)
			
			* Load the CWZ moving block test data
			qui use "$prdir/dta/analysis/qcew/moving_block_pval/resid_`lhs'_ind`ind'_event_year_`e'.dta", clear
							
			* Put the p-values in a matrix
			qui sum p, d
			mat cwz_p_`ind'_`z'month = r(mean)
		}
					
		* Combine these matrices across 6- and 12-month estimates and LHS variables
		if "`lhs'" == "ln_emp" {
			mat effect`ind' = effect`ind'_6month, effect`ind'_12month
			mat mspe_ratio`ind' = mspe_ratio`ind'_6month, mspe_ratio`ind'_12month
			mat mspe_pval`ind' = mspe_pval`ind'_6month, mspe_pval`ind'_12month
			mat andrews_p_`ind' = andrews_p_`ind'_6month, andrews_p_`ind'_12month
			mat cwz_p_`ind' = cwz_p_`ind'_6month, cwz_p_`ind'_12month
			mat N`ind' = N`ind'_6month, N`ind'_12month
			mat mspe_stars`ind' = mspe_stars`ind'_6month, mspe_stars`ind'_12month
		}
		else if "`lhs'" != "ln_emp" {
			mat effect`ind' = effect`ind', effect`ind'_6month, effect`ind'_12month
			mat mspe_ratio`ind' = mspe_ratio`ind', mspe_ratio`ind'_6month, mspe_ratio`ind'_12month
			mat mspe_pval`ind' = mspe_pval`ind', mspe_pval`ind'_6month, mspe_pval`ind'_12month
			mat andrews_p_`ind' = andrews_p_`ind', andrews_p_`ind'_6month, andrews_p_`ind'_12month
			mat cwz_p_`ind' = cwz_p_`ind', cwz_p_`ind'_6month, cwz_p_`ind'_12month
			mat N`ind' = N`ind', N`ind'_6month, N`ind'_12month
			mat mspe_stars`ind' = mspe_stars`ind', mspe_stars`ind'_6month, mspe_stars`ind'_12month
		}	
			
		* Combine the matrices into one
		mat vals`ind' = effect`ind'
		mat mspevals`ind' = mspe_ratio`ind'\mspe_pval`ind'\andrews_p_`ind'\cwz_p_`ind'
		
		* Now make the tables *if* we've looped through to the last lhs variable (ln_estabs)
		if "`lhs'" == "ln_estabs" {
										
			* Make the combined tables
			frmttable using "$prdir/out/analysis/cz_7400/tables/combined/qcew_naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
			annotate(mspe_stars`ind') asymbol(*,**,***) ///
			ctitles("`industry'","Log","","","Log compensation","","Log",""\"`industry2'","employment","","","per worker","","establishments",""\"","6 month TE","12 month TE","6 month TE","12 month TE","6 month TE","12 month TE") ///
			rtitles("Treatment effect")
						
			frmttable using "$prdir/out/analysis/cz_7400/tables/combined/qcew_naics_`ind'", replace tex statmat(mspevals`ind') sdec(4) ///
			rtitles("RMSPE"\"RMSPE \textit{p}-val"\"Andrews \textit{p}-val"\"Moving block \textit{p}-val") append
						
			frmttable using "$prdir/out/analysis/cz_7400/tables/combined/qcew_naics_`ind'", replace tex statmat(N`ind') sdec(0) ///
			rtitles("N") append
		}
	}
}
	
* Close the log file
log close sublog
