capture log close sublog
log using "$prdir/log/analysis/qwi/alt_p_values_6month.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Calculate the two-sided p-values for the Orlando estimated effects
* Author: Justin Wiltshire
	
* Updated: November 2, 2019
*-------------------------------------------------------------------------------

* Loop over the different QWI data sets
foreach dem in nonhisp hsorless {

	* For treated unit
	local treat_cz = 7400

	* Run employment synthetic control for treated CZ, selected NAICS supersectors
	foreach ind of numlist 10 23 44 72 {
			 
		* Set up the loop for the outcome variables
		foreach lhs in ln_emp ln_avg_wkly_wage ln_wagebill {
						
			* Set up the loop to yield six-month impacts
			local m = 0
			local z = `m' + 6
									
			* Load the data
			use "$prdir/dta/analysis/qwi/`dem'/sc_merged/cz_`treat_cz'/resid_`lhs'/deseasonalize_n`ind'_merged.dta", clear
				
			* Rename the Orlando TE
			rename tr_effect_orl tr_effect_7400

			* Reshape the data
			qui reshape long tr_effect_, i(time) j(cz)
			sort cz time
				
			* Normalize all treatment effects to that in the last pre-treatment period
			bysort cz: gen ct = _n
			qui sum ct if time == 229
			local normalize = r(mean)
			bysort cz: gen pre_te = tr_effect[`normalize']
			bysort cz: egen pretreat_te = max(pre_te)
			qui replace tr_effect = tr_effect - pretreat_te
											
			* Generate the MSPE ratio
			qui gen mspe_pre = .
			qui gen mspe_post`z'month = .
			qui distinct time
			local post_periods = r(ndistinct) - 15
			levelsof(cz), local(cz)
			foreach c of local cz {
				egen mspe_pre_`c' = total(tr_effect^2) if cz == `c' & time < 230
				replace mspe_pre = mspe_pre_`c'/14 if cz == `c'
				egen mspe_post`z'month_`c' = total(tr_effect^2) if cz == `c' & inrange(time, 230, 232)
				replace mspe_post`z'month = mspe_post`z'month_`c'/`post_periods' if cz == `c'
				drop mspe_pre_`c' mspe_post`z'month_`c'
			}
			bysort cz (mspe_pre): replace mspe_pre = mspe_pre[1]
			bysort cz (mspe_post`z'month): replace mspe_post`z'month = mspe_post`z'month[1]
			qui gen ratio`z'month = mspe_post`z'month/mspe_pre
			qui keep if time == 232
										
			* Keep only variables we want
			keep cz tr_effect ratio*
								
			* Get the number of placebo CZs
			local j = _N - 1
			qui gen donor_sample_size = `j'
		
			* Generate the Orlando ranking
			sort ratio`z'month
			qui gen rank_ratio`z'month = _n
										
			* Keep only the relevant observation
			keep if cz == 7400

			* Generate the p-values
			qui gen p_value_ratio`z'month = (1 + `j' + 1 - rank_ratio`z'month)/(`j' + 1)
					
			* Keep variables of interest and merge with the other pseudo p-value data
			keep cz tr_effect ratio* rank donor_sample_size p_value*
			compress
			save "$prdir/dta/analysis/qwi/`dem'/sc_pvalue/cz_`treat_cz'/resid_`lhs'/alt_p_values_n`ind'_month`z'.dta", replace	
		}
	}
		
	*---------------------------------------------------------------------------
	* Make the tables
	*---------------------------------------------------------------------------

	* Loop over six- and twelve-month impacts
	local z = 6

	* Loop over the LHS variables
	foreach lhs in ln_emp ln_wagebill ln_avg_wkly_wage {
					 
		* Loop over the NAICS supersectors
		foreach ind of numlist 10 23 44 72 {
					
			* Define the industry labels
			if "`ind'" == "10" {
				local industry "Total"
				local industry2 ""
			}
			else if "`ind'" == "23" {
				local industry "Construction"
				local industry2 ""
			}
			else if "`ind'" == "44" {
				local industry "Retail"
				local industry2 ""
			}
			else if "`ind'" == "72" {
				local industry "Accommodation \&"
				local industry2 "Food Services"
			}
					
			* Load the data
			qui use "$prdir/dta/analysis/qwi/`dem'/sc_pvalue/cz_`treat_cz'/resid_`lhs'/alt_p_values_n`ind'_month`z'.dta", clear
							
			* Put the key figures in a matrix
			if "`lhs'" == "ln_emp" {
				qui sum tr_effect, d
				mat effect`ind' = r(mean)
				qui sum ratio`z'month, d
				mat mspe_ratio`ind' = r(mean)
				qui sum p_value_ratio`z'month, d
				mat mspe_pval`ind' = r(mean)
				mat mspe_stars`ind' = (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
				qui sum donor_sample_size, d
				mat N`ind' = r(mean) + 1
			}	
			else if "`lhs'" != "ln_emp" {
				qui sum tr_effect, d
				mat effect`ind' = effect`ind', r(mean)
				qui sum ratio`z'month, d
				mat mspe_ratio`ind' = mspe_ratio`ind', r(mean)
				qui sum p_value_ratio`z'month, d
				mat mspe_pval`ind' = mspe_pval`ind', r(mean)
				mat mspe_stars`ind' = mspe_stars`ind', (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
				qui sum donor_sample_size, d
				mat N`ind' = N`ind', (r(mean) + 1)
			}
							
			* Now make the tables *if* we've looped through to the last lhs variable (ln_avg_wkly_wage)
			if "`lhs'" == "ln_avg_wkly_wage" {
				
				* Combine the matrices into one
				mat vals`ind' = effect`ind'
				mat mspevals`ind' = mspe_ratio`ind'\mspe_pval`ind'
						
				* Make the individual tables
				frmttable using "$prdir/out/analysis/qwi/`dem'/cz_`treat_cz'/tables/`z'_month/alt_`dem'_naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
				annotate(mspe_stars`ind') asymbol(*,**,***) ///
				ctitles("`industry'","Log","Log total","Log compensation"\"`industry2'","employment","compensation","per worker") ///
				rtitles("Treatment effect")
				
				frmttable using "$prdir/out/analysis/qwi/`dem'/cz_`treat_cz'/tables/`z'_month/alt_`dem'_naics_`ind'", replace tex statmat(mspevals`ind') sdec(4) ///
				rtitles("RMSPE"\"RMSPE p-value") append
					
				frmttable using "$prdir/out/analysis/qwi/`dem'/cz_`treat_cz'/tables/`z'_month/alt_`dem'_naics_`ind'", replace tex statmat(N`ind') sdec(0) ///
				rtitles("N") append
			}
		}
	}
}

* Close the log file
log close sublog		
