capture log close sublog
log using "$prdir/log/analysis/qwi/synth_ctrls_6month.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Synthetic control analysis of deseasonalized QWI variables, by CZ
* Author: Justin Wiltshire

* Updated: September 14, 2021
*-------------------------------------------------------------------------------

tempfile core

* Set Orlando as the treated unit
local c = 7400  

* Loop over the different QWI data sets
foreach dem in nonhisp nonhisp_white lessthanhs hsorless somecollplus {

	* Load the cleaned and deseasonalized QWI data sets
	qui use "$prdir/dta/cln/qwi/deseasonalized_qwi_naics_cz_`dem'.dta", clear
	  
	* Change settings for the synthetic control
	qui set matsize 11000
	  
	* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
	foreach z of numlist $cz_droplist {
		if "`c'" != "`z'" {
			drop if cz == `z'
		}
	}

	* Keep for 2014 and later (after the recovery had firmly taken root)
	keep if year >= 2014
	  
	* Save the tempfile
	save "`core'", replace

	* Loop over the different industries
	foreach ind of numlist 10 23 44 72 {
		use "`core'", clear
		local pdflist_`ind'
			
		* Restrict the donor pool to CZs of appropriate size
		qui sum emp if naics == `ind', d
		keep if emp >= r(p75) & naics == `ind'
			
		* Keep the industry of interest  
		keep if naics == `ind'
		  
		* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
		bysort cz: egen ct = count(ln_emp)
		qui sum ct, d
		qui gen rmax = r(max)
		qui sum ct if cz == `c', d
		if r(N) == rmax {
			keep if ct == rmax
				
			* Set up and run the synthetic control estimations
			tsset cz tm
			
			* Synthetic control for each of the LHS variables
			foreach lhs of varlist resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill {
				
				* Non-employment variables are only observed quarterly
				keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
			
				* Note the particular run
				di "Treated CZ `c'; NAICS `ind'; LHS `lhs'"
				
				#delimit ;
					qui synth 
						`lhs' `lhs'(688) `lhs'(685) `lhs'(682) `lhs'(679) `lhs'(676) `lhs'(673) `lhs'(661) `lhs'(655) `lhs'(649)
						prop_emp_23(649(3)688) prop_emp_72(649(3)688), trunit(`c') trperiod(691) fig 
						keep("$prdir/dta/analysis/qwi/`dem'/sc_results_dta`donors'/cz_`c'/`lhs'/deseasonalize_n`ind'.dta") replace;
					#delimit cr 
								  
				tempfile g`ind'
				nicepdf "`g`ind''.pdf"
				local pdflist_`ind' "`pdflist_`ind'' `g`ind''.pdf"
			}
		}
	}
}
	
* Close the log file
log close sublog
