capture log close sublog
log using "$prdir/log/analysis/qwi/synth_placebo_qwi_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Run placebo tests for synthetic control analysis of
* deseasonalized QWI variables, by CZ, extended to a one-year treated period
* Some states are missing obs
* Author: Justin Wiltshire
	
* Updated: September 14, 2021
*-------------------------------------------------------------------------------

tempfile core

* Set Orlando as the treated unit
local c = 7400  

* Loop over the different QWI data sets
foreach dem in nonhisp lessthanhs hsorless somecollplus {

	* Load the cleaned and deseasonalized QWI data sets
	qui use "$prdir/dta/cln/qwi/deseasonalized_qwi_naics_cz_`dem'_1year.dta", clear
	  
	* Change settings for the synthetic control
	qui set matsize 11000
	  
	* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
	foreach z of numlist $cz_droplist {
		if "`c'" != "`z'" {
			drop if cz == `z'
		}
	}

	* Keep for 2014 and later (after the recovery had firmly taken root)
	keep if year >= 2014
	 
	* Save the tempfile
	save "`core'", replace

	* Loop over the different industries
	foreach ind of numlist 10 23 44 72 {
		use "`core'", clear
			
		* Restrict the donor pool to CZs of appropriate size
		qui sum emp if naics == `ind', d
		keep if emp >= r(p75) & naics == `ind'
			
		* Keep the industry of interest  
		keep if naics == `ind'
		  
		* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
		bysort cz: egen ct = count(ln_emp)
		qui sum ct, d
		qui gen rmax = r(max)
		qui sum ct if cz == `c', d
		if r(N) == rmax {
			keep if ct == rmax
			
			* Save the second tempfile
			tempfile core2
			save "`core2'"
			  
			* Run through each of the donor pools CZs as a placebo test
			levelsof(cz), local(CZ)
			foreach czone of local CZ {
				if "`czone'" != "`c'" {
					use "`core2'", clear
					  
					* Set up and run the synthetic control estimations
					tsset cz tm
					
					* Synthetic control for each of the LHS variables
					foreach lhs of varlist resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill {
				
						* Non-employment variables are only observed quarterly
						keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
					
						* Note the particular run
						di "Placebo treated CZ `czone' for treated CZ `c'; NAICS `ind'; LHS `lhs'"
						
						#delimit ;
							qui synth 
								`lhs' `lhs'(688) `lhs'(685) `lhs'(682) `lhs'(679) `lhs'(676) `lhs'(673) `lhs'(661) `lhs'(655) `lhs'(649)
								prop_emp_23(649(3)688) prop_emp_72(649(3)688), trunit(`czone') trperiod(691) fig 
								keep("$prdir/dta/analysis/qwi/`dem'/sc_placebo_tests/cz_`c'/`lhs'/n`ind'_cz`czone'_1year.dta") replace;
						#delimit cr
					}
				}
			}
		}
	}
}
					
* Close the log file
log close sublog
