capture log close sublog
log using "$prdir/log/build/deseasonalize_qwi_naics_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Deseasonalize the QWI data files by CZ for each industry, 
* extending the treated period to one year out (some states are missing obs)
* Author: Justin Wiltshire
	
* Updated: July 31, 2020
*-------------------------------------------------------------------------------

* Loop over different samples of interest
foreach dem in nonhisp nonhisp_white lessthanhs hsorless somecollplus {

	* Load the QWI CZ data
	use "$prdir/dta/cln/qwi/qwi_naics_cz_`dem'.dta", clear

	* Create month variable
	gen month = month(dofm(tm))

	* Create employment-industry proportions to be controls
	if "`dem'" != "somecollplus" {
		bysort cz tm (naics): gen prop_emp_23 = prop_emp[2]
		bysort cz tm (naics): gen prop_emp_44 = prop_emp[5]
		bysort cz tm (naics): gen prop_emp_72 = prop_emp[8]
	}
	if "`dem'" == "somecollplus" {
		bysort cz tm (naics): gen prop_emp_23 = prop_emp[2]
		bysort cz tm (naics): gen prop_emp_44 = prop_emp[3]
		bysort cz tm (naics): gen prop_emp_72 = prop_emp[4]
	}

	keep if inlist(naics, 10, 23, 44, 72)
	
	tempfile core
	save "`core'"

	* Deseasonalize key variables by CZ
	levelsof(naics), local(naics)
	foreach ind of local naics {
	  
	  ** Log employment **
	  * Re-load the main file and restrict to ind
	  qui use "`core'", clear
	  keep if naics == `ind'
	  
	  * Keep only CZs with employment observations at least once in each quarter
	  bysort cz quarter: egen obs_cz_qtr = count(ln_emp)
	  qui gen flag_zeros = 1 if obs_cz_qtr == 0
	  bysort cz: egen flag_drop = count(flag_zeros)
	  drop if flag_drop > 0
	  drop obs_cz_qtr flag*
	  
	  * Initialize residual employment then populate it
	  qui gen resid_ln_emp = .
	  quietly levelsof cz, local(cz)
	  foreach z of local cz {
		di "TYPE: `dem'; NAICS `ind'; ln_emp; Commuting Zone `z'"
		qui reg ln_emp i.month if cz == `z'
		qui predict double resid_ln_emp_`z' if cz == `z', residuals
		qui replace resid_ln_emp = resid_ln_emp_`z' if cz == `z'
		drop resid_ln_emp_`z'
	  }
	  * Compress and save
	  compress
	  save "$prdir/dta/cln/qwi/qwi_naics`ind'_cz_`dem'_1year.dta", replace
	  
	  ** Log wagebill, log establishments, and log average weekly wage
	  * Re-load the main file and restrict to ind
	  foreach v of varlist ln_avg_wkly_wage ln_wagebill { 
		qui use "`core'", clear
		keep if naics == `ind'
		keep if inlist(month, 2, 5, 8, 11)
		
		* Keep only CZs with variables observations at least once in each quarter
		bysort cz quarter: egen obs_cz_qtr = count(`v')
		qui gen flag_zeros = 1 if obs_cz_qtr == 0
		bysort cz: egen flag_drop = count(flag_zeros)
		drop if flag_drop > 0
		drop obs_cz_qtr flag*
		
		* Initialize residual variable then populate it
		qui gen resid_`v' = .
		quietly levelsof cz, local(cz)
		foreach z of local cz {
		  di "TYPE: `dem'; NAICS `ind'; `v'; Commuting Zone `z'"
		  qui reg `v' i.month if cz == `z'
		  qui predict double resid_`v'_`z' if cz == `z', residuals
		  qui replace resid_`v' = resid_`v'_`z' if cz == `z'
		  drop resid_`v'_`z'
		}
		* Compress, merge and save
		compress
		merge 1:1 cz tm using "$prdir/dta/cln/qwi/qwi_naics`ind'_cz_`dem'_1year.dta", nogenerate
		save "$prdir/dta/cln/qwi/qwi_naics`ind'_cz_`dem'_1year.dta", replace
	  }
	}

	* Append the datasets together, restrict to pre 2018Q1, and save
	foreach ind of local naics {
		if "`ind'" == "10" {
			use "$prdir/dta/cln/qwi/qwi_naics`ind'_cz_`dem'_1year.dta", clear
		}
		else if "`ind'" != "10" {
			append using "$prdir/dta/cln/qwi/qwi_naics`ind'_cz_`dem'_1year.dta"
		}
		erase "$prdir/dta/cln/qwi/qwi_naics`ind'_cz_`dem'_1year.dta"
	}
	save "$prdir/dta/cln/qwi/deseasonalized_qwi_naics_cz_`dem'_1year.dta", replace
}

* Close the log file
log close sublog
