do settings
capture log close sublog
log using "$prdir/log/build/qcew/qcew_builder.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Prepare QCEW data at different levels of aggregation, 1990-2018
* Author: Justin Wiltshire (adapted from a file by Brendan Price)
*
* Last modified: October 2, 2019
*-------------------------------------------------------------------------------

* Source directory
local srcdir "$prdir/dta/src/qcew"
local clndir "$prdir/dta/cln/qcew"

* Year lists: NAICS-coded data
local naics_yearlist "1990/2018"

* Pre-process NAICS codes
capture program drop preprocess_naics_codes
program define preprocess_naics_codes
	rename industry_code naics
	assert inlist(naics, "31-33", "44-45", "48-49") if regexm(naics, "-")	
	assert !inlist(naics, "31", "44", "48")
	replace naics = "31" if naics =="31-33"
	replace naics = "44" if naics == "44-45"
	replace naics = "48" if naics == "48-49"
	destring naics, replace
end

*-------------------------------------------------------------------------------
* Prepare NAICS codebook files
*-------------------------------------------------------------------------------

* Set local f = 1 if downloading all files again
local f = 1

* Industry names
#delimit ;
	copy 
		"https://data.bls.gov/cew/doc/titles/industry/industry_titles.csv"
		"`srcdir'/cbk/industry_titles.csv", replace ;
	#delimit cr
import delimited using "`srcdir'/cbk/industry_titles.csv", varnames(1) clear
rename industry_code naics
assert inlist(naics, "31-33", "44-45", "48-49") if regexm(naics, "-")	
assert !inlist(naics, "31", "44", "48")
replace naics = "31" if naics =="31-33"
replace naics = "44" if naics == "44-45"
replace naics = "48" if naics == "48-49"
destring naics, replace
labmask naics, values(industry_title) lblname(naics_lbl)
drop industry_title
tempfile naics_industry_titles
save "`naics_industry_titles'"

* Ownership
#delimit ;
	copy 
		"https://data.bls.gov/cew/doc/titles/ownership/ownership_titles.csv"
		"`srcdir'/cbk/ownership_titles.csv", replace ;
	#delimit cr
import delimited using "`srcdir'/cbk/ownership_titles.csv", varnames(1) clear
labmask own_code, values(own_title) lblname(own_code_lbl)
drop own_title
tempfile naics_ownership
save "`naics_ownership'"

* Save a readme file if the data were downloaded in this run
if `f' == 1 {
	qui clear
	qui set obs 1
	qui gen readme = "Codebooks downloaded on $S_DATE from: https://www.bls.gov/cew/downloadable-data-files.htm"
	export delimited readme using "$prdir/dta/src/qcew/zip/readme.txt", replace novarnames
}

*-------------------------------------------------------------------------------
* Loop over years of NAICS data
*-------------------------------------------------------------------------------

	foreach y of numlist `naics_yearlist' {
		
		* Progress report
		di "Progress: NAICS `y' ($S_DATE $S_TIME)"

		* Download the file
		#delimit ;
			copy 
				"https://data.bls.gov/cew/data/files/`y'/csv/`y'_qtrly_singlefile.zip"
				"`srcdir'/zip/`y'_qtrly_singlefile.zip", replace ;
			#delimit cr
			
		* Unzip the file
		cd "`srcdir'/zip"
		unzipfile "`srcdir'/zip/`y'_qtrly_singlefile.zip"
		
		* Load dataset
		import delimited using "`srcdir'/zip/`y'.q1-q4.singlefile.csv", clear
		erase "`srcdir'/zip/`y'.q1-q4.singlefile.csv"
		erase "`srcdir'/zip/`y'_qtrly_singlefile.zip"

		* Restrict to variables of interest
		#delimit ;
		keep
			area_fips
			own_code
			industry_code
			size_code
			year
			qtr
			disclosure_code
			qtrly_estabs
			month1_emplvl
			month2_emplvl
			month3_emplvl
			total_qtrly_wages;
		#delimit cr

		* Keep all national/state observations and high-level county observations within the 50 states + DC
		rename industry_code naics
		assert inlist(naics, "31-33", "44-45", "48-49") if regexm(naics, "-")	
		assert !inlist(naics, "31", "44", "48")
		replace naics = "31" if naics =="31-33"
		replace naics = "44" if naics == "44-45"
		replace naics = "48" if naics == "48-49"
		destring naics, replace
		keep if area_fips == "US000" | (inrange(real(area_fips), 1000, 56000) & substr(area_fips, 3, 3) == "000") | (inrange(real(area_fips), 1000, 56999) & inlist(naics, 10, 11, 21, 22, 23, 31, 42, 44, 48, 51, 52, 53, 54, 55, 56, 61, 62, 71, 72, 81, 92))
				
		* Numeric geographic codes
		replace area_fips = "00000" if area_fips == "US000"
		destring area_fips, replace
	
		* Drop overseas, out-of-state, and unclassified counties
		drop if inlist(mod(area_fips, 1000), 996, 997, 998, 999)

		* Level of geographic aggregation
		gen byte agg_geo = .
		replace agg_geo = 0 if area_fips == 00000
		replace agg_geo = 1 if inrange(area_fips, 1000, 56000) & mod(area_fips, 1000) == 0
		replace agg_geo = 2 if inrange(area_fips, 1000, 56999) & mod(area_fips, 1000) != 0
		assert agg_geo != .

		* Drop size breakdown
		keep if size_code == 0
		drop size_code

		* Verify data structure
		bysort area_fips naics own_code year qtr: assert _N == 1

		* Apply value labels
		quietly merge m:1 naics using "`naics_industry_titles'", assert(2 3) keep(3) nogenerate update
		quietly merge m:1 own_code using "`naics_ownership'", assert(2 3) keep(3) nogenerate update
				
		* Simplify variable names
		rename month1_emplvl emp1
		rename month2_emplvl emp2
		rename month3_emplvl emp3

		* Tag suppressed cells
		assert inlist(disclosure_code, "N", "-") if !mi(disclosure_code)
		gen byte sup = inlist(disclosure_code, "N", "-")
		drop disclosure_code
		
		* Stack months
		reshape long emp, i(area_fips naics own_code year qtr) j(month)
		replace month = 3 * (qtr - 1) + month
		drop qtr

		* Code quarterly establishments + wages as recorded in the middle of each quarter
		replace qtrly_estabs = . if !inlist(month, 2, 5, 8, 11)
		replace total_qtrly_wages = . if !inlist(month, 2, 5, 8, 11)
		rename qtrly_estabs estabs
		rename total_qtrly_wages wagebill

		* Reshape to deal with ownership categories
		reshape wide emp estabs wagebill sup, i(area_fips naics year month) j(own_code)
		order area_fips naics year month emp* estabs* wagebill*
	
		* Flag the presence of missing values: (i) aggregate, (ii) private, and (iii) fed/state/local gov't
		gen byte flag_agg = (sup0 == 1)
		gen byte flag_prv = (sup5 == 1)
		gen byte flag_gov = (sup1 == 1 | sup2 == 1 | sup3 == 1)
		
		* Sanity-check additional ownership categories present 
		* Total employment (almost) equals UI-covered employment plus federal employment
		assert (area_fips == 00000 & naics == 10) == !mi(emp9)
		assert abs(emp0 - emp1 - emp9) <= 1000 if area_fips == 00000 & naics == 10
		drop emp9 estabs9 wagebill9 sup9

		* Total government employment equals sum of federal, state, and local government employment
		assert (inlist(agg_geo, 0, 1) & naics == 10) == !mi(emp8)
		assert abs(emp8 - emp1 - emp2 - emp3) == 0 if inlist(agg_geo, 0, 1) & area_fips != 11000 & naics == 10
		drop emp8 estabs8 wagebill8 sup8

		* Totals are directly reported only for aggregate employment
		assert naics == 10 if !mi(emp0, estabs0, wagebill0)		
		
		* Record employment, establishments, and wage bill within each industry
		foreach v in "emp" "estabs" "wagebill" {
			* Direct measure of aggregate activity
			rename `v'0 `v'_agg
			
			* Indirect measure obtained by summing across all ownership categories
			capture confirm var `v'4
			if _rc != 0 gen `v'4 = .
			egen `v'_sub = rowtotal(`v'1 `v'2 `v'3 `v'4 `v'5)
			
			* Use direct measures when possible, indirect measures otherwise
			gen `v' = .
			replace `v' = `v'_agg if !mi(`v'_agg) & flag_agg == 0
			replace `v' = `v'_sub if mi(`v')
		}

		* Calendar time
		gen int tm = ym(year, month)
		format %tm tm
		
		* Store the extract
		keep area_fips naics agg_geo tm emp estabs wagebill flag_agg flag_prv flag_gov 
		sort area_fips naics agg_geo tm
		order area_fips naics agg_geo tm emp estabs wagebill flag_agg flag_prv flag_gov 
		
		* Store for merging
		compress		
		save "`clndir'/byyear/qcew_naics_`y'.dta", replace
	}

*-------------------------------------------------------------------------------
* Stack data across years
*-------------------------------------------------------------------------------

	* Stack datasets
	clear
	foreach y of numlist `naics_yearlist' {
		append using "`clndir'/byyear/qcew_naics_`y'.dta"
	}
	
	* Store data
	tempfile core
	save "`core'"
	
	* Retain and save county-level data
	keep if agg_geo == 2
	rename area_fips cty_fips
	drop agg_geo
			
	* Map into county codes consistent with eventual aggregation to 1990 CZs
	cty_remap
			
	* Aggregate up
	collapse (sum) emp estabs wagebill (max) flag_agg flag_prv flag_gov, by(cty_fips naics tm)

	* Cleanup		
	label var cty_fips "County FIPS code"
				
	* Deflate wage bill
	merge m:1 tm using "$prdir/cw/pce/dta/cln/pce_mth.dta", assert(2 3) keep(3) keepusing(pce) nogenerate
	replace wagebill = wagebill/pce
	drop pce
		
	* Set establishment counts and wage-bill to missing in off-months
	assert estabs == 0 & wagebill == 0 if !inlist(month(dofm(tm)), 2, 5, 8, 11)
	replace estabs = . if !inlist(month(dofm(tm)), 2, 5, 8, 11)
	replace wagebill = . if !inlist(month(dofm(tm)), 2, 5, 8, 11)		

	* Label variables
	label var naics "NAICS/supersector code"
	label var tm "Year/month"
	label var emp "Employment (reported total)"
	label var estabs "Establishment count (reported total)"
	label var wagebill "Real wage bill (reported total)"
	label var flag_agg "Aggregate totals are suppressed"
	label var flag_prv "Private-sector totals are at least partly suppressed"
	label var flag_gov "Government-sector totals are at least partly suppressed"

	* Save combined extract
	compress
	sort cty_fips naics tm
	order cty_fips naics tm emp estabs wagebill flag_agg flag_prv flag_gov
	describe, fullnames
	save "`clndir'/qcew_naics_cty.dta", replace

* Close the log file
log close sublog
